@@ -9,7 +9,7 @@ use dokuwiki\HTTP\DokuHTTPClient;
  *
  * Replaces SimplePie's own class
  */
-class FeedParserFile extends \SimplePie_File
+class FeedParserFile extends \SimplePie\File
 {
     protected $http;
     /** @noinspection PhpMissingParentConstructorInspection */
@@ -37,7 +37,7 @@ class FeedParserFile extends \SimplePie_File
         $this->body = $this->http->resp_body;
         $this->error = $this->http->error;
 
-        $this->method = SIMPLEPIE_FILE_SOURCE_REMOTE | SIMPLEPIE_FILE_SOURCE_FSOCKOPEN;
+        $this->method = \SimplePie\SimplePie::FILE_SOURCE_REMOTE | \SimplePie\SimplePie::FILE_SOURCE_FSOCKOPEN;
 
         return $this->success;
     }
