@@ -9,16 +9,11 @@
  * @author     Andreas Gohr <andi@splitbrain.org>
  */
 
-if(!defined('DOKU_INC')) die('meh.');
-
-// some ACL level defines
-define('AUTH_NONE', 0);
-define('AUTH_READ', 1);
-define('AUTH_EDIT', 2);
-define('AUTH_CREATE', 4);
-define('AUTH_UPLOAD', 8);
-define('AUTH_DELETE', 16);
-define('AUTH_ADMIN', 255);
+use dokuwiki\Extension\AuthPlugin;
+use dokuwiki\Extension\Event;
+use dokuwiki\Extension\PluginController;
+use dokuwiki\PassHash;
+use dokuwiki\Subscriptions\RegistrationSubscriptionSender;
 
 /**
  * Initialize the auth system.
@@ -34,13 +29,13 @@ define('AUTH_ADMIN', 255);
  */
 function auth_setup() {
     global $conf;
-    /* @var DokuWiki_Auth_Plugin $auth */
+    /* @var AuthPlugin $auth */
     global $auth;
     /* @var Input $INPUT */
     global $INPUT;
     global $AUTH_ACL;
     global $lang;
-    /* @var Doku_Plugin_Controller $plugin_controller */
+    /* @var PluginController $plugin_controller */
     global $plugin_controller;
     $AUTH_ACL = array();
 
@@ -61,7 +56,7 @@ function auth_setup() {
 
     if ($auth->success == false) {
         // degrade to unauthenticated user
-        unset($auth);
+        $auth = null;
         auth_logoff();
         msg($lang['authtempfail'], -1);
         return false;
@@ -71,22 +66,18 @@ function auth_setup() {
     $INPUT->set('http_credentials', false);
     if(!$conf['rememberme']) $INPUT->set('r', false);
 
-    // handle renamed HTTP_AUTHORIZATION variable (can happen when a fix like
-    // the one presented at
-    // http://www.besthostratings.com/articles/http-auth-php-cgi.html is used
-    // for enabling HTTP authentication with CGI/SuExec)
-    if(isset($_SERVER['REDIRECT_HTTP_AUTHORIZATION']))
-        $_SERVER['HTTP_AUTHORIZATION'] = $_SERVER['REDIRECT_HTTP_AUTHORIZATION'];
-    // streamline HTTP auth credentials (IIS/rewrite -> mod_php)
-    if(isset($_SERVER['HTTP_AUTHORIZATION'])) {
-        list($_SERVER['PHP_AUTH_USER'], $_SERVER['PHP_AUTH_PW']) =
-            explode(':', base64_decode(substr($_SERVER['HTTP_AUTHORIZATION'], 6)));
+    // Populate Basic Auth user/password from Authorization header
+    // Note: with FastCGI, data is in REDIRECT_HTTP_AUTHORIZATION instead of HTTP_AUTHORIZATION
+    $header = $INPUT->server->str('HTTP_AUTHORIZATION') ?: $INPUT->server->str('REDIRECT_HTTP_AUTHORIZATION');
+    if(preg_match( '~^Basic ([a-z\d/+]*={0,2})$~i', $header, $matches )) {
+        $userpass = explode(':', base64_decode($matches[1]));
+        list($_SERVER['PHP_AUTH_USER'], $_SERVER['PHP_AUTH_PW']) = $userpass;
     }
 
     // if no credentials were given try to use HTTP auth (for SSO)
-    if(!$INPUT->str('u') && empty($_COOKIE[DOKU_COOKIE]) && !empty($_SERVER['PHP_AUTH_USER'])) {
-        $INPUT->set('u', $_SERVER['PHP_AUTH_USER']);
-        $INPUT->set('p', $_SERVER['PHP_AUTH_PW']);
+    if (!$INPUT->str('u') && empty($_COOKIE[DOKU_COOKIE]) && !empty($INPUT->server->str('PHP_AUTH_USER'))) {
+        $INPUT->set('u', $INPUT->server->str('PHP_AUTH_USER'));
+        $INPUT->set('p', $INPUT->server->str('PHP_AUTH_PW'));
         $INPUT->set('http_credentials', true);
     }
 
@@ -96,17 +87,21 @@ function auth_setup() {
         $INPUT->set('p', stripctl($INPUT->str('p')));
     }
 
-    if(!is_null($auth) && $auth->canDo('external')) {
-        // external trust mechanism in place
-        $auth->trustExternal($INPUT->str('u'), $INPUT->str('p'), $INPUT->bool('r'));
-    } else {
+    $ok = null;
+    if (!is_null($auth) && $auth->canDo('external')) {
+        $ok = $auth->trustExternal($INPUT->str('u'), $INPUT->str('p'), $INPUT->bool('r'));
+    }
+
+    if ($ok === null) {
+        // external trust mechanism not in place, or returns no result,
+        // then attempt auth_login
         $evdata = array(
             'user'     => $INPUT->str('u'),
             'password' => $INPUT->str('p'),
             'sticky'   => $INPUT->bool('r'),
             'silent'   => $INPUT->bool('http_credentials')
         );
-        trigger_event('AUTH_LOGIN_CHECK', $evdata, 'auth_login_wrapper');
+        Event::createAndTrigger('AUTH_LOGIN_CHECK', $evdata, 'auth_login_wrapper');
     }
 
     //load ACL into a global array XXX
@@ -135,7 +130,7 @@ function auth_loadACL() {
     $out = array();
     foreach($acl as $line) {
         $line = trim($line);
-        if(empty($line) || ($line{0} == '#')) continue; // skip blank lines & comments
+        if(empty($line) || ($line[0] == '#')) continue; // skip blank lines & comments
         list($id,$rest) = preg_split('/[ \t]+/',$line,2);
 
         // substitute user wildcard first (its 1:1)
@@ -150,10 +145,12 @@ function auth_loadACL() {
         // substitute group wildcard (its 1:m)
         if(strstr($line, '%GROUP%')){
             // if user is not logged in, grps is empty, no output will be added (i.e. skipped)
-            foreach((array) $USERINFO['grps'] as $grp){
-                $nid   = str_replace('%GROUP%',cleanID($grp),$id);
-                $nrest = str_replace('%GROUP%','@'.auth_nameencode($grp),$rest);
-                $out[] = "$nid\t$nrest";
+            if(isset($USERINFO['grps'])){
+                foreach((array) $USERINFO['grps'] as $grp){
+                    $nid   = str_replace('%GROUP%',cleanID($grp),$id);
+                    $nrest = str_replace('%GROUP%','@'.auth_nameencode($grp),$rest);
+                    $out[] = "$nid\t$nrest";
+                }
             }
         } else {
             $out[] = "$id\t$rest";
@@ -211,7 +208,7 @@ function auth_login($user, $pass, $sticky = false, $silent = false) {
     global $USERINFO;
     global $conf;
     global $lang;
-    /* @var DokuWiki_Auth_Plugin $auth */
+    /* @var AuthPlugin $auth */
     global $auth;
     /* @var Input $INPUT */
     global $INPUT;
@@ -244,19 +241,21 @@ function auth_login($user, $pass, $sticky = false, $silent = false) {
             // we got a cookie - see if we can trust it
 
             // get session info
-            $session = $_SESSION[DOKU_COOKIE]['auth'];
-            if(isset($session) &&
-                $auth->useSessionCache($user) &&
-                ($session['time'] >= time() - $conf['auth_security_timeout']) &&
-                ($session['user'] == $user) &&
-                ($session['pass'] == sha1($pass)) && //still crypted
-                ($session['buid'] == auth_browseruid())
-            ) {
+            if (isset($_SESSION[DOKU_COOKIE])) {
+                $session = $_SESSION[DOKU_COOKIE]['auth'];
+                if (isset($session) &&
+                    $auth->useSessionCache($user) &&
+                    ($session['time'] >= time() - $conf['auth_security_timeout']) &&
+                    ($session['user'] == $user) &&
+                    ($session['pass'] == sha1($pass)) && //still crypted
+                    ($session['buid'] == auth_browseruid())
+                ) {
 
-                // he has session, cookie and browser right - let him in
-                $INPUT->server->set('REMOTE_USER', $user);
-                $USERINFO               = $session['info']; //FIXME move all references to session
-                return true;
+                    // he has session, cookie and browser right - let him in
+                    $INPUT->server->set('REMOTE_USER', $user);
+                    $USERINFO = $session['info']; //FIXME move all references to session
+                    return true;
+                }
             }
             // no we don't trust it yet - recheck pass but silent
             $secret = auth_cookiesalt(!$sticky, true); //bind non-sticky to session
@@ -278,19 +277,22 @@ function auth_login($user, $pass, $sticky = false, $silent = false) {
  *
  * @author  Andreas Gohr <andi@splitbrain.org>
  *
- * @return  string  a MD5 sum of various browser headers
+ * @return  string  a SHA256 sum of various browser headers
  */
 function auth_browseruid() {
     /* @var Input $INPUT */
     global $INPUT;
 
-    $ip  = clientIP(true);
-    $uid = '';
-    $uid .= $INPUT->server->str('HTTP_USER_AGENT');
-    $uid .= $INPUT->server->str('HTTP_ACCEPT_CHARSET');
-    $uid .= substr($ip, 0, strpos($ip, '.'));
-    $uid = strtolower($uid);
-    return md5($uid);
+    $ip = clientIP(true);
+    // convert IP string to packed binary representation
+    $pip = inet_pton($ip);
+
+    $uid = implode("\n", [
+        $INPUT->server->str('HTTP_USER_AGENT'),
+        $INPUT->server->str('HTTP_ACCEPT_LANGUAGE'),
+        substr($pip, 0, strlen($pip) / 2), // use half of the IP address (works for both IPv4 and IPv6)
+    ]);
+    return hash('sha256', $uid);
 }
 
 /**
@@ -407,7 +409,7 @@ function auth_decrypt($ciphertext, $secret) {
 function auth_logoff($keepbc = false) {
     global $conf;
     global $USERINFO;
-    /* @var DokuWiki_Auth_Plugin $auth */
+    /* @var AuthPlugin $auth */
     global $auth;
     /* @var Input $INPUT */
     global $INPUT;
@@ -440,18 +442,19 @@ function auth_logoff($keepbc = false) {
  *
  * The info is available through $INFO['ismanager'], too
  *
- * @author Andreas Gohr <andi@splitbrain.org>
+ * @param string $user Username
+ * @param array $groups List of groups the user is in
+ * @param bool $adminonly when true checks if user is admin
+ * @param bool $recache set to true to refresh the cache
+ * @return bool
  * @see    auth_isadmin
  *
- * @param  string $user       Username
- * @param  array  $groups     List of groups the user is in
- * @param  bool   $adminonly  when true checks if user is admin
- * @return bool
+ * @author Andreas Gohr <andi@splitbrain.org>
  */
-function auth_ismanager($user = null, $groups = null, $adminonly = false) {
+function auth_ismanager($user = null, $groups = null, $adminonly = false, $recache=false) {
     global $conf;
     global $USERINFO;
-    /* @var DokuWiki_Auth_Plugin $auth */
+    /* @var AuthPlugin $auth */
     global $auth;
     /* @var Input $INPUT */
     global $INPUT;
@@ -465,17 +468,32 @@ function auth_ismanager($user = null, $groups = null, $adminonly = false) {
             $user = $INPUT->server->str('REMOTE_USER');
         }
     }
-    if(is_null($groups)) {
-        $groups = (array) $USERINFO['grps'];
+    if (is_null($groups)) {
+        // checking the logged in user, or another one?
+        if ($USERINFO && $user === $INPUT->server->str('REMOTE_USER')) {
+            $groups =  (array) $USERINFO['grps'];
+        } else {
+            $groups = $auth->getUserData($user);
+            $groups = $groups ? $groups['grps'] : [];
+        }
     }
 
-    // check superuser match
-    if(auth_isMember($conf['superuser'], $user, $groups)) return true;
-    if($adminonly) return false;
-    // check managers
-    if(auth_isMember($conf['manager'], $user, $groups)) return true;
+    // prefer cached result
+    static $cache = [];
+    $cachekey = serialize([$user, $adminonly, $groups]);
+    if (!isset($cache[$cachekey]) || $recache) {
+        // check superuser match
+        $ok = auth_isMember($conf['superuser'], $user, $groups);
 
-    return false;
+        // check managers
+        if (!$ok && !$adminonly) {
+            $ok = auth_isMember($conf['manager'], $user, $groups);
+        }
+
+        $cache[$cachekey] = $ok;
+    }
+
+    return $cache[$cachekey];
 }
 
 /**
@@ -485,15 +503,16 @@ function auth_ismanager($user = null, $groups = null, $adminonly = false) {
  *
  * The info is available through $INFO['isadmin'], too
  *
+ * @param string $user Username
+ * @param array $groups List of groups the user is in
+ * @param bool $recache set to true to refresh the cache
+ * @return bool
  * @author Andreas Gohr <andi@splitbrain.org>
  * @see auth_ismanager()
  *
- * @param  string $user       Username
- * @param  array  $groups     List of groups the user is in
- * @return bool
  */
-function auth_isadmin($user = null, $groups = null) {
-    return auth_ismanager($user, $groups, true);
+function auth_isadmin($user = null, $groups = null, $recache=false) {
+    return auth_ismanager($user, $groups, true, $recache);
 }
 
 /**
@@ -508,14 +527,14 @@ function auth_isadmin($user = null, $groups = null) {
  * @return bool       true for membership acknowledged
  */
 function auth_isMember($memberlist, $user, array $groups) {
-    /* @var DokuWiki_Auth_Plugin $auth */
+    /* @var AuthPlugin $auth */
     global $auth;
     if(!$auth) return false;
 
     // clean user and groups
     if(!$auth->isCaseSensitive()) {
-        $user   = utf8_strtolower($user);
-        $groups = array_map('utf8_strtolower', $groups);
+        $user   = \dokuwiki\Utf8\PhpString::strtolower($user);
+        $groups = array_map([\dokuwiki\Utf8\PhpString::class, 'strtolower'], $groups);
     }
     $user   = $auth->cleanUser($user);
     $groups = array_map(array($auth, 'cleanGroup'), $groups);
@@ -529,7 +548,7 @@ function auth_isMember($memberlist, $user, array $groups) {
     // compare cleaned values
     foreach($members as $member) {
         if($member == '@ALL' ) return true;
-        if(!$auth->isCaseSensitive()) $member = utf8_strtolower($member);
+        if(!$auth->isCaseSensitive()) $member = \dokuwiki\Utf8\PhpString::strtolower($member);
         if($member[0] == '@') {
             $member = $auth->cleanGroup(substr($member, 1));
             if(in_array($member, $groups)) return true;
@@ -560,7 +579,7 @@ function auth_quickaclcheck($id) {
     global $INPUT;
     # if no ACL is used always return upload rights
     if(!$conf['useacl']) return AUTH_UPLOAD;
-    return auth_aclcheck($id, $INPUT->server->str('REMOTE_USER'), $USERINFO['grps']);
+    return auth_aclcheck($id, $INPUT->server->str('REMOTE_USER'), is_array($USERINFO) ? $USERINFO['grps'] : array());
 }
 
 /**
@@ -576,12 +595,12 @@ function auth_quickaclcheck($id) {
  */
 function auth_aclcheck($id, $user, $groups) {
     $data = array(
-        'id'     => $id,
+        'id'     => $id ?? '',
         'user'   => $user,
         'groups' => $groups
     );
 
-    return trigger_event('AUTH_ACL_CHECK', $data, 'auth_aclcheck_cb');
+    return Event::createAndTrigger('AUTH_ACL_CHECK', $data, 'auth_aclcheck_cb');
 }
 
 /**
@@ -601,12 +620,13 @@ function auth_aclcheck_cb($data) {
 
     global $conf;
     global $AUTH_ACL;
-    /* @var DokuWiki_Auth_Plugin $auth */
+    /* @var AuthPlugin $auth */
     global $auth;
 
     // if no ACL is used always return upload rights
     if(!$conf['useacl']) return AUTH_UPLOAD;
     if(!$auth) return AUTH_NONE;
+    if(!is_array($AUTH_ACL)) return AUTH_NONE;
 
     //make sure groups is an array
     if(!is_array($groups)) $groups = array();
@@ -617,8 +637,8 @@ function auth_aclcheck_cb($data) {
     }
 
     if(!$auth->isCaseSensitive()) {
-        $user   = utf8_strtolower($user);
-        $groups = array_map('utf8_strtolower', $groups);
+        $user   = \dokuwiki\Utf8\PhpString::strtolower($user);
+        $groups = array_map([\dokuwiki\Utf8\PhpString::class, 'strtolower'], $groups);
     }
     $user   = auth_nameencode($auth->cleanUser($user));
     $groups = array_map(array($auth, 'cleanGroup'), (array) $groups);
@@ -644,7 +664,7 @@ function auth_aclcheck_cb($data) {
             $match = preg_replace('/#.*$/', '', $match); //ignore comments
             $acl   = preg_split('/[ \t]+/', $match);
             if(!$auth->isCaseSensitive() && $acl[1] !== '@ALL') {
-                $acl[1] = utf8_strtolower($acl[1]);
+                $acl[1] = \dokuwiki\Utf8\PhpString::strtolower($acl[1]);
             }
             if(!in_array($acl[1], $groups)) {
                 continue;
@@ -674,7 +694,7 @@ function auth_aclcheck_cb($data) {
                 $match = preg_replace('/#.*$/', '', $match); //ignore comments
                 $acl   = preg_split('/[ \t]+/', $match);
                 if(!$auth->isCaseSensitive() && $acl[1] !== '@ALL') {
-                    $acl[1] = utf8_strtolower($acl[1]);
+                    $acl[1] = \dokuwiki\Utf8\PhpString::strtolower($acl[1]);
                 }
                 if(!in_array($acl[1], $groups)) {
                     continue;
@@ -733,7 +753,7 @@ function auth_nameencode($name, $skip_group = false) {
     if($name == '%GROUP%') return $name;
 
     if(!isset($cache[$name][$skip_group])) {
-        if($skip_group && $name{0} == '@') {
+        if($skip_group && $name[0] == '@') {
             $cache[$name][$skip_group] = '@'.preg_replace_callback(
                 '/([\x00-\x2f\x3a-\x40\x5b-\x60\x7b-\x7f])/',
                 'auth_nameencode_callback', substr($name, 1)
@@ -778,7 +798,7 @@ function auth_pwgen($foruser = '') {
         'foruser'  => $foruser
     );
 
-    $evt = new Doku_Event('AUTH_PASSWORD_GENERATE', $data);
+    $evt = new Event('AUTH_PASSWORD_GENERATE', $data);
     if($evt->advise_before(true)) {
         $c = 'bcdfghjklmnprstvwz'; //consonants except hard to speak ones
         $v = 'aeiou'; //vowels
@@ -792,7 +812,7 @@ function auth_pwgen($foruser = '') {
             $data['password'] .= $a[auth_random(0, strlen($a) - 1)];
         }
         //... and add a nice number and special
-        $data['password'] .= auth_random(10, 99).$s[auth_random(0, strlen($s) - 1)];
+        $data['password'] .= $s[auth_random(0, strlen($s) - 1)].auth_random(10, 99);
     }
     $evt->advise_after();
 
@@ -810,7 +830,7 @@ function auth_pwgen($foruser = '') {
  */
 function auth_sendPassword($user, $password) {
     global $lang;
-    /* @var DokuWiki_Auth_Plugin $auth */
+    /* @var AuthPlugin $auth */
     global $auth;
     if(!$auth) return false;
 
@@ -827,7 +847,7 @@ function auth_sendPassword($user, $password) {
     );
 
     $mail = new Mailer();
-    $mail->to($userinfo['name'].' <'.$userinfo['mail'].'>');
+    $mail->to($mail->getCleanName($userinfo['name']).' <'.$userinfo['mail'].'>');
     $mail->subject($lang['regpwmail']);
     $mail->setBody($text, $trep);
     return $mail->send();
@@ -845,7 +865,7 @@ function auth_sendPassword($user, $password) {
 function register() {
     global $lang;
     global $conf;
-    /* @var DokuWiki_Auth_Plugin $auth */
+    /* @var \dokuwiki\Extension\AuthPlugin $auth */
     global $auth;
     global $INPUT;
 
@@ -887,8 +907,8 @@ function register() {
     }
 
     // send notification about the new user
-    $subscription = new Subscription();
-    $subscription->send_register($login, $fullname, $email);
+    $subscription = new RegistrationSubscriptionSender();
+    $subscription->sendRegister($login, $fullname, $email);
 
     // are we done?
     if(!$conf['autopasswd']) {
@@ -914,7 +934,7 @@ function register() {
 function updateprofile() {
     global $conf;
     global $lang;
-    /* @var DokuWiki_Auth_Plugin $auth */
+    /* @var AuthPlugin $auth */
     global $auth;
     /* @var Input $INPUT */
     global $INPUT;
@@ -1003,7 +1023,7 @@ function updateprofile() {
 function auth_deleteprofile(){
     global $conf;
     global $lang;
-    /* @var DokuWiki_Auth_Plugin $auth */
+    /* @var \dokuwiki\Extension\AuthPlugin $auth */
     global $auth;
     /* @var Input $INPUT */
     global $INPUT;
@@ -1057,7 +1077,7 @@ function auth_deleteprofile(){
 function act_resendpwd() {
     global $lang;
     global $conf;
-    /* @var DokuWiki_Auth_Plugin $auth */
+    /* @var AuthPlugin $auth */
     global $auth;
     /* @var Input $INPUT */
     global $INPUT;
@@ -1072,7 +1092,7 @@ function act_resendpwd() {
     if($token) {
         // we're in token phase - get user info from token
 
-        $tfile = $conf['cachedir'].'/'.$token{0}.'/'.$token.'.pwauth';
+        $tfile = $conf['cachedir'].'/'.$token[0].'/'.$token.'.pwauth';
         if(!file_exists($tfile)) {
             msg($lang['resendpwdbadauth'], -1);
             $INPUT->remove('pwauth');
@@ -1147,7 +1167,7 @@ function act_resendpwd() {
 
         // generate auth token
         $token = md5(auth_randombytes(16)); // random secret
-        $tfile = $conf['cachedir'].'/'.$token{0}.'/'.$token.'.pwauth';
+        $tfile = $conf['cachedir'].'/'.$token[0].'/'.$token.'.pwauth';
         $url   = wl('', array('do'=> 'resendpwd', 'pwauth'=> $token), true, '&');
 
         io_saveFile($tfile, $user);
@@ -1225,7 +1245,7 @@ function auth_verifyPassword($clear, $crypt) {
  */
 function auth_setCookie($user, $pass, $sticky) {
     global $conf;
-    /* @var DokuWiki_Auth_Plugin $auth */
+    /* @var AuthPlugin $auth */
     global $auth;
     global $USERINFO;
 
@@ -1257,7 +1277,7 @@ function auth_getCookie() {
     if(!isset($_COOKIE[DOKU_COOKIE])) {
         return array(null, null, null);
     }
-    list($user, $sticky, $pass) = explode('|', $_COOKIE[DOKU_COOKIE], 3);
+    list($user, $sticky, $pass) = sexplode('|', $_COOKIE[DOKU_COOKIE], 3, '');
     $sticky = (bool) $sticky;
     $pass   = base64_decode($pass);
     $user   = base64_decode($user);
