@@ -221,7 +221,11 @@ function getRecents($first, $num, $ns = '', $flags = 0) {
         } else {
             $lines_position--;
             $x = $rec;
-            if ($flags & RECENTS_MEDIA_CHANGES) $x['media'] = true;
+            if ($flags & RECENTS_MEDIA_CHANGES){
+                $x['media'] = true;
+            } else {
+                $x['media'] = false;
+            }
             $rec = false;
         }
         if (--$first >= 0) continue; // skip first entries
