@@ -3,6 +3,9 @@
 /**
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
  *
+ * @author Ramdziana F Y <ramdzian@gmail.com>
+ * @author NawanP <saya@nawan.my.id>
+ * @author rusly-id <rusly-id@users.noreply.github.com>
  * @author mubaidillah <mubaidillah@gmail.com>
  * @author Irwan Butar Butar <irwansah.putra@gmail.com>
  * @author Yustinus Waruwu <juswaruwu@gmail.com>
@@ -23,6 +26,7 @@ $lang['btn_show']              = 'Tampilkan halaman';
 $lang['btn_create']            = 'Buat halaman baru';
 $lang['btn_search']            = 'Cari';
 $lang['btn_save']              = 'Simpan';
+$lang['btn_preview']           = 'Pratayang';
 $lang['btn_top']               = 'kembali ke atas';
 $lang['btn_newer']             = '<< lebih lanjut';
 $lang['btn_older']             = 'sebelumnya >>';
@@ -31,6 +35,7 @@ $lang['btn_recent']            = 'Perubahan terbaru';
 $lang['btn_upload']            = 'Upload';
 $lang['btn_cancel']            = 'Batal';
 $lang['btn_index']             = 'Indeks';
+$lang['btn_secedit']           = 'Sunting';
 $lang['btn_login']             = 'Login';
 $lang['btn_logout']            = 'Keluar';
 $lang['btn_admin']             = 'Admin';
@@ -40,7 +45,9 @@ $lang['btn_back']              = 'Kembali';
 $lang['btn_backlink']          = 'Backlinks';
 $lang['btn_subscribe']         = 'Ikuti Perubahan';
 $lang['btn_profile']           = 'Ubah Profil';
+$lang['btn_reset']             = 'Atur ulang';
 $lang['btn_resendpwd']         = 'Atur password baru';
+$lang['btn_draft']             = 'Sunting draf';
 $lang['btn_recover']           = 'Cadangkan draf';
 $lang['btn_draftdel']          = 'Hapus draft';
 $lang['btn_revert']            = 'Kembalikan';
@@ -64,43 +71,9 @@ $lang['badlogin']              = 'Maaf, username atau password salah.';
 $lang['badpassconfirm']        = 'Maaf, password salah';
 $lang['minoredit']             = 'Perubahan Minor';
 $lang['draftdate']             = 'Simpan draft secara otomatis';
-$lang['regmissing']            = 'Maaf, Anda harus mengisi semua field.';
-$lang['reguexists']            = 'Maaf, user dengan user login ini telah ada.';
-$lang['regsuccess']            = 'User telah didaftarkan dan password telah dikirim ke email Anda.';
-$lang['regsuccess2']           = 'User telah dibuatkan.';
-$lang['regmailfail']           = 'Kami menemukan kesalahan saat mengirimkan password ke alamat email Anda. Mohon hubungi administrator.';
-$lang['regbadmail']            = 'Alamat email yang Anda masukkan tidak valid - jika menurut Anda hal ini adalah kesalahan sistem, mohon hubungi admin.';
-$lang['regbadpass']            = 'Passwod yang dimasukkan tidak sama. Silahkan ulangi lagi.';
-$lang['regpwmail']             = 'Password DokuWiki Anda';
-$lang['reghere']               = 'Anda belum mempunyai account? silahkan ';
-$lang['profna']                = 'Wiki ini tidak mengijinkan perubahan profil.';
-$lang['profnochange']          = 'Tidak ada perubahan.';
-$lang['profnoempty']           = 'Mohon mengisikan nama atau alamat email.';
-$lang['profchanged']           = 'Profil User berhasil diubah.';
-$lang['profnodelete']          = 'Wiki ini tidak mendukung penghapusan pengguna';
-$lang['profdeleteuser']        = 'Hapus Akun';
-$lang['profdeleted']           = 'Akun anda telah dihapus dari wiki ini';
-$lang['profconfdelete']        = 'Saya berharap menghapus akun saya dari wiki ini.
-Aksi ini tidak bisa diselesaikan.';
-$lang['profconfdeletemissing'] = 'Knfirmasi check box tidak tercentang';
-$lang['pwdforget']             = 'Lupa Password? Dapatkan yang baru';
-$lang['resendna']              = 'Wiki ini tidak mendukung pengiriman ulang password.';
-$lang['resendpwd']             = 'Atur password baru';
-$lang['resendpwdmissing']      = 'Maaf, Anda harus mengisikan semua field.';
-$lang['resendpwdnouser']       = 'Maaf, user ini tidak ditemukan.';
-$lang['resendpwdbadauth']      = 'Maaf, kode autentikasi tidak valid. Pastikan Anda menggunakan keseluruhan link konfirmasi.';
-$lang['resendpwdconfirm']      = 'Link konfirmasi telah dikirim melalui email.';
-$lang['resendpwdsuccess']      = 'Password baru Anda telah dikirim melalui email.';
-$lang['license']               = 'Kecuali jika dinyatakan lain, konten pada wiki ini dilisensikan dibawah lisensi berikut:';
-$lang['licenseok']             = 'Catatan: Dengan menyunting halaman ini, Anda setuju untuk melisensikan konten Anda dibawah lisensi berikut:';
-$lang['searchmedia']           = 'Cari nama file:';
-$lang['searchmedia_in']        = 'Cari di %s';
-$lang['txt_upload']            = 'File yang akan diupload:';
-$lang['txt_filename']          = 'Masukkan nama wiki (opsional):';
-$lang['txt_overwrt']           = 'File yang telah ada akan ditindih';
-$lang['maxuploadsize']         = 'Unggah maks. %s per berkas';
-$lang['lockedby']              = 'Sedang dikunci oleh:';
-$lang['lockexpire']            = 'Penguncian artikel sampai dengan:';
+$lang['searchcreatepage']      = 'Jika anda tidak menemukan yang anda cari, anda dapat membuat atau mengedit halaman %s, yang dinamai sesuai kueri anda.';
+$lang['search_fullresults']    = 'Hasil teks penuh';
+$lang['js']['search_toggle_tools'] = 'Tombol Alihan Perkakas Telusur';
 $lang['js']['willexpire']      = 'Halaman yang sedang Anda kunci akan berakhir dalam waktu kurang lebih satu menit.\nUntuk menghindari konflik, gunakan tombol Preview untuk me-reset timer pengunci.';
 $lang['js']['notsavedyet']     = 'Perubahan yang belum disimpan akan hilang.\nYakin akan dilanjutkan?';
 $lang['js']['searchmedia']     = 'Cari file';
@@ -136,12 +109,66 @@ $lang['js']['restore_confirm'] = 'Benar-benar ingin mengembalikan versi ini?';
 $lang['js']['media_diff']      = 'Lihat perbedaan:';
 $lang['js']['media_diff_both'] = 'Berdampingan';
 $lang['js']['media_diff_opacity'] = 'Mencolok';
+$lang['js']['media_diff_portions'] = 'Usap';
 $lang['js']['media_select']    = 'Pilih file...';
 $lang['js']['media_upload_btn'] = 'Unggah';
 $lang['js']['media_done_btn']  = 'Selesai';
 $lang['js']['media_drop']      = 'Tarik file disini untuk mengunggah';
 $lang['js']['media_cancel']    = 'Buang';
 $lang['js']['media_overwrt']   = 'Timpa berkas yang ada';
+$lang['js']['data_insecure']   = 'PERINGATAN: Sepertinya direktori data anda belum diamankan. Silakan baca <a href="https://www.dokuwiki.org/security#web_access_security">Keamanan Akses Web di DokuWiki</a>.';
+$lang['search_exact_match']    = 'Tepat sesuai';
+$lang['search_starts_with']    = 'Dimulai dengan';
+$lang['search_ends_with']      = 'Diakhiri dengan';
+$lang['search_contains']       = 'Berisi';
+$lang['search_custom_match']   = 'Kustom';
+$lang['search_any_ns']         = 'Namespace apa saja';
+$lang['search_any_time']       = 'Kapanpun';
+$lang['search_past_7_days']    = 'Pekan lalu';
+$lang['search_past_month']     = 'Bulan lalu';
+$lang['search_past_year']      = 'Tahun lalu';
+$lang['search_sort_by_hits']   = 'Urutkan berdasar hit';
+$lang['search_sort_by_mtime']  = 'Urutkan berdasar perubahan terkini';
+$lang['regmissing']            = 'Maaf, Anda harus mengisi semua field.';
+$lang['reguexists']            = 'Maaf, user dengan user login ini telah ada.';
+$lang['regsuccess']            = 'User telah didaftarkan dan password telah dikirim ke email Anda.';
+$lang['regsuccess2']           = 'User telah dibuatkan.';
+$lang['regfail']               = 'Pengguna tidak dapat dibuat.';
+$lang['regmailfail']           = 'Kami menemukan kesalahan saat mengirimkan password ke alamat email Anda. Mohon hubungi administrator.';
+$lang['regbadmail']            = 'Alamat email yang Anda masukkan tidak valid - jika menurut Anda hal ini adalah kesalahan sistem, mohon hubungi admin.';
+$lang['regbadpass']            = 'Passwod yang dimasukkan tidak sama. Silahkan ulangi lagi.';
+$lang['regpwmail']             = 'Password DokuWiki Anda';
+$lang['reghere']               = 'Anda belum mempunyai account? silahkan ';
+$lang['profna']                = 'Wiki ini tidak mengijinkan perubahan profil.';
+$lang['profnochange']          = 'Tidak ada perubahan.';
+$lang['profnoempty']           = 'Mohon mengisikan nama atau alamat email.';
+$lang['profchanged']           = 'Profil User berhasil diubah.';
+$lang['profnodelete']          = 'Wiki ini tidak mendukung penghapusan pengguna';
+$lang['profdeleteuser']        = 'Hapus Akun';
+$lang['profdeleted']           = 'Akun anda telah dihapus dari wiki ini';
+$lang['profconfdelete']        = 'Saya berharap menghapus akun saya dari wiki ini.
+Aksi ini tidak bisa diselesaikan.';
+$lang['profconfdeletemissing'] = 'Knfirmasi check box tidak tercentang';
+$lang['proffail']              = 'Profil pengguna tidak diperbarui.';
+$lang['pwdforget']             = 'Lupa Password? Dapatkan yang baru';
+$lang['resendna']              = 'Wiki ini tidak mendukung pengiriman ulang password.';
+$lang['resendpwd']             = 'Atur password baru';
+$lang['resendpwdmissing']      = 'Maaf, Anda harus mengisikan semua field.';
+$lang['resendpwdnouser']       = 'Maaf, user ini tidak ditemukan.';
+$lang['resendpwdbadauth']      = 'Maaf, kode autentikasi tidak valid. Pastikan Anda menggunakan keseluruhan link konfirmasi.';
+$lang['resendpwdconfirm']      = 'Link konfirmasi telah dikirim melalui email.';
+$lang['resendpwdsuccess']      = 'Password baru Anda telah dikirim melalui email.';
+$lang['license']               = 'Kecuali jika dinyatakan lain, konten pada wiki ini dilisensikan dibawah lisensi berikut:';
+$lang['licenseok']             = 'Catatan: Dengan menyunting halaman ini, Anda setuju untuk melisensikan konten Anda dibawah lisensi berikut:';
+$lang['searchmedia']           = 'Cari nama file:';
+$lang['searchmedia_in']        = 'Cari di %s';
+$lang['txt_upload']            = 'File yang akan diupload:';
+$lang['txt_filename']          = 'Masukkan nama wiki (opsional):';
+$lang['txt_overwrt']           = 'File yang telah ada akan ditindih';
+$lang['maxuploadsize']         = 'Unggah maks. %s per berkas';
+$lang['allowedmime']           = 'Daftar ekstensi berkas yang diizinkan';
+$lang['lockedby']              = 'Sedang dikunci oleh:';
+$lang['lockexpire']            = 'Penguncian artikel sampai dengan:';
 $lang['rssfailed']             = 'Error terjadi saat mengambil feed: ';
 $lang['nothingfound']          = 'Tidak menemukan samasekali.';
 $lang['mediaselect']           = 'Pilihan Mediafile';
@@ -167,6 +194,7 @@ $lang['mediaextchange']        = 'Ektensi file berubah dari .%s ke .%s';
 $lang['reference']             = 'Referensi untuk';
 $lang['ref_inuse']             = 'File tidak dapat dihapus karena sedang digunakan oleh halaman:';
 $lang['ref_hidden']            = 'Beberapa referensi ada didalam halaman yang tidak diijinkan untuk Anda baca.';
+$lang['hits']                  = 'Hit';
 $lang['quickhits']             = 'Matching pagenames';
 $lang['toc']                   = 'Daftar isi';
 $lang['current']               = 'sekarang';
@@ -180,6 +208,8 @@ $lang['diff_side']             = 'Berdampingan';
 $lang['diffprevrev']           = 'Revisi sebelumnya';
 $lang['diffnextrev']           = 'Revisi selanjutnya';
 $lang['difflastrev']           = 'Revisi terakhir';
+$lang['diffbothprevrev']       = 'Kedua sisi revisi sebelumnya';
+$lang['diffbothnextrev']       = 'Kedua sisi revisi setelahnya';
 $lang['line']                  = 'Baris';
 $lang['breadcrumb']            = 'Jejak:';
 $lang['youarehere']            = 'Anda disini:';
@@ -189,7 +219,8 @@ $lang['deleted']               = 'terhapus';
 $lang['created']               = 'dibuat';
 $lang['restored']              = 'revisi lama ditampilkan kembali (%s)';
 $lang['external_edit']         = 'Perubahan eksternal';
-$lang['noflash']               = '<a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> diperlukan untuk menampilkan konten ini.';
+$lang['summary']               = 'Edit ringkasan';
+$lang['noflash']               = '<a href="http://get.adobe.com/flashplayer">Adobe Flash Plugin</a> diperlukan untuk menampilkan konten ini.';
 $lang['download']              = 'Unduh Cuplikan';
 $lang['tools']                 = 'Alat';
 $lang['user_tools']            = 'Alat Pengguna';
@@ -211,6 +242,7 @@ $lang['qb_italic']             = 'Miring';
 $lang['qb_underl']             = 'Garis Bawah';
 $lang['qb_code']               = 'Kode';
 $lang['qb_strike']             = 'Text Tercoret';
+$lang['qb_h1']                 = 'Tajuk Level 1';
 $lang['qb_hs']                 = 'Pilih Judul';
 $lang['qb_hplus']              = 'Judul Lebih Atas';
 $lang['qb_hminus']             = 'Judul Lebih Bawah';
@@ -256,7 +288,7 @@ $lang['i_installer']           = 'Instalasi DokuWiki';
 $lang['i_wikiname']            = 'Nama Wiki';
 $lang['i_enableacl']           = 'Aktifkan ACL (disarankan)';
 $lang['i_problems']            = 'Terdapat beberapa kesalahan seperti berikut. Anda tidak dapat melanjutkan sampai kesalahan tersebut diperbaiki.';
-$lang['i_modified']            = 'Untuk alasan keamanan, skrip ini hanya dapat dijalankan pada instalasi DikuWiki baru dan belum di modifikasi. Silahkan meng-ekstrak kembali berkasi dari halaman dowload, atau lihat   <a href="http://dokuwiki.org/install">Dokuwiki installation instructions</a> ';
+$lang['i_modified']            = 'Untuk alasan keamanan, skrip ini hanya dapat dijalankan pada instalasi DikuWiki baru dan belum di modifikasi. Silahkan meng-ekstrak kembali berkasi dari halaman dowload, atau lihat   <a href="https://www.dokuwiki.org/install">Dokuwiki installation instructions</a> ';
 $lang['i_funcna']              = 'Fungsi PHP <code>%s</code> tidak tersedia. Mungkin dinonaktifkan oleh layanan hosting Anda?';
 $lang['i_phpver']              = 'Versi PHP Anda <code>%s</code> lebih rendah dari yang dibutuhkan <code>%s</code>. Mohon melakukan upgrade.';
 $lang['i_permfail']            = '<code>%s</code> tidak dapat ditulis oleh DokuWiki. Anda harus memperbaiki konfigurasi hak akses untuk direktori tersebut.';
@@ -308,5 +340,5 @@ $lang['media_restore']         = 'Kembalikan versi ini';
 $lang['currentns']             = 'Namespace saat ini';
 $lang['searchresult']          = 'Hasil Pencarian';
 $lang['wikimarkup']            = 'Markah Wiki';
-$lang['email_signature_text'] = 'Email ini dibuat otomatis oleh DokuWiki
+$lang['email_signature_text']  = 'Email ini dibuat otomatis oleh DokuWiki
 @DOKUWIKIURL@';
