@@ -3,6 +3,7 @@
 /**
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
  *
+ * @author Jose Luis Sanches <jose.reis.sanches@gmail.com>
  * @author Gustavo B. Schenkel <gustavo.schenkel@gmail.com>
  * @author Paulo <pschopf@gmail.com>
  * @author Mario AlexandTeixeira dos Santos <masterofclan@gmail.com>
@@ -52,7 +53,7 @@ $lang['btn_update']            = 'Atualizar';
 $lang['btn_delete']            = 'Excluir';
 $lang['btn_back']              = 'Voltar';
 $lang['btn_backlink']          = 'Backlinks';
-$lang['btn_subscribe']         = 'Gerenciar Subscrições';
+$lang['btn_subscribe']         = 'Gerir Subscrições';
 $lang['btn_profile']           = 'Atualizar Perfil';
 $lang['btn_reset']             = 'Redefinir';
 $lang['btn_resendpwd']         = 'Definir nova senha';
@@ -62,10 +63,10 @@ $lang['btn_draftdel']          = 'Apagar rascunho';
 $lang['btn_revert']            = 'Restaurar';
 $lang['btn_register']          = 'Registar';
 $lang['btn_apply']             = 'Aplicar';
-$lang['btn_media']             = 'Gerenciador de Mídia';
-$lang['btn_deleteuser']        = 'Remover Minha Conta';
+$lang['btn_media']             = 'Gestor de Media';
+$lang['btn_deleteuser']        = 'Remover a Minha Conta';
 $lang['btn_img_backto']        = 'De volta a %s';
-$lang['btn_mediaManager']      = 'Ver no gerenciador de mídia';
+$lang['btn_mediaManager']      = 'Ver no gestor de media';
 $lang['loggedinas']            = 'Está em sessão como:';
 $lang['user']                  = 'Utilizador';
 $lang['pass']                  = 'Senha';
@@ -75,13 +76,13 @@ $lang['passchk']               = 'mais uma vez';
 $lang['remember']              = 'Lembrar?';
 $lang['fullname']              = 'Nome completo';
 $lang['email']                 = 'E-mail';
-$lang['profile']               = 'Perfil do Usuário';
-$lang['badlogin']              = 'Usuário ou ou senha inválida.';
+$lang['profile']               = 'Perfil do Utilizador';
+$lang['badlogin']              = 'Utilizador ou ou senha inválida.';
 $lang['badpassconfirm']        = 'Infelizmente a senha não é a correta';
 $lang['minoredit']             = 'Alterações Menores';
 $lang['draftdate']             = 'Rascunho automaticamente gravado em';
 $lang['nosecedit']             = 'A página foi modificada. Como a informação da seção estava desatualizada, foi carregada a página inteira.';
-$lang['searchcreatepage']      = 'Se não encontrou o que estava procurando, pode criar uma nova página com o nome %s.';
+$lang['searchcreatepage']      = 'Se não encontrou o que procurava, pode criar uma nova página com o nome %s.';
 $lang['search_fullresults']    = 'O que foi encontrado nos textos';
 $lang['js']['search_toggle_tools'] = 'Mudar Ferramenta de Pesquisa';
 $lang['js']['willexpire']      = 'O bloqueio de edição para este documento irá expirar em um minuto.\nPara evitar conflitos use o botão prever para reiniciar o temporizador de bloqueio.';
@@ -109,8 +110,8 @@ $lang['js']['medianolink']     = 'Não linkar à imagem';
 $lang['js']['medialeft']       = 'Alinhar a imagem à esquerda.';
 $lang['js']['mediaright']      = 'Alinhar a imagem à direita.';
 $lang['js']['mediacenter']     = 'Alinhar a imagem ao centro.';
-$lang['js']['medianoalign']    = 'Não usar alinhamento algum.';
-$lang['js']['nosmblinks']      = 'Linkar a pastas Windows compartilhadas apenas funciona com o Microsoft Internet Explorer.\nVocê pode no entanto copiar e colar o link.';
+$lang['js']['medianoalign']    = 'Não usar nenhum alinhamento.';
+$lang['js']['nosmblinks']      = 'Linkar a pasta Windows compartilhada apenas funciona com o Microsoft Internet Explorer.\nPode no entanto copiar e colar o link.';
 $lang['js']['linkwiz']         = 'Assistente de Criação de Link';
 $lang['js']['linkto']          = 'Link para:';
 $lang['js']['del_confirm']     = 'Remover o(s) item(s) selecionados?';
@@ -125,7 +126,7 @@ $lang['js']['media_done_btn']  = 'Feito';
 $lang['js']['media_drop']      = 'Largue arquivo aqui para enviar';
 $lang['js']['media_cancel']    = 'excluir';
 $lang['js']['media_overwrt']   = 'Escrever por cima de arquivos existentes';
-$lang['js']['data_insecure']   = 'AVISO: Parece que seu diretório de dados não está devidamente protegido. Por favor leia sobre <a href="https://www.dokuwiki.org/security#web_access_security">Segurança de acesso à web em DokuWiki</a>.';
+$lang['js']['data_insecure']   = 'AVISO: Parece que o seu diretório de dados não está devidamente protegido. Por favor leia sobre <a href="https://www.dokuwiki.org/security#web_access_security">Segurança de acesso à web em DokuWiki</a>.';
 $lang['search_exact_match']    = 'Correspondência exata';
 $lang['search_starts_with']    = 'Começa por';
 $lang['search_ends_with']      = 'Termina em';
@@ -139,35 +140,35 @@ $lang['search_past_year']      = 'Ano passado';
 $lang['search_sort_by_hits']   = 'Ordenar por ocorrência';
 $lang['search_sort_by_mtime']  = 'Ordenar pela última alteração';
 $lang['regmissing']            = 'Por favor, preencha todos os campos.';
-$lang['reguexists']            = 'Este usuário já está inscrito. Por favor escolha outro nome de usuário.';
-$lang['regsuccess']            = 'O usuário foi criado e a senha foi enviada para o endereço de correio eletrônico usado na inscrição.';
-$lang['regsuccess2']           = 'O usuário foi criado.';
-$lang['regfail']               = 'O usuário não pode ser criado.';
+$lang['reguexists']            = 'Este utilizador já está inscrito. Por favor escolha outro nome de utilizador.';
+$lang['regsuccess']            = 'O utilizador foi criado e a senha foi enviada para o endereço de correio eletrónico usado na inscrição.';
+$lang['regsuccess2']           = 'O utilizador foi criado.';
+$lang['regfail']               = 'O utilizador não pode ser criado.';
 $lang['regmailfail']           = 'Houve um erro no envio da senha por e-mail. Por favor, contacte o administrador!';
-$lang['regbadmail']            = 'O endereço de correio eletrônico é inválido. Se o endereço está correto e isto é um erro, contacte o administrador!';
+$lang['regbadmail']            = 'O endereço de correio eletrónico é inválido. Se o endereço está correto e isto é um erro, contacte o administrador!';
 $lang['regbadpass']            = 'As duas senhas não são idênticas, por favor tente de novo.';
 $lang['regpwmail']             = 'A sua senha DokuWiki';
-$lang['reghere']               = 'Ainda não tem uma conta? Registre-se';
+$lang['reghere']               = 'Ainda não tem uma conta? Registe-se';
 $lang['profna']                = 'Este Wiki não suporta modificações nos perfis';
 $lang['profnochange']          = 'Nenhuma alteração, nada a fazer.';
 $lang['profnoempty']           = 'Não são permitidos nomes ou e-mails em branco.';
-$lang['profchanged']           = 'Perfil do usuário atualizado com sucesso.';
+$lang['profchanged']           = 'Perfil do utilizador atualizado com sucesso.';
 $lang['profnodelete']          = 'Este wiki não suporta remoção de utilizadores';
 $lang['profdeleteuser']        = 'Apagar Conta';
 $lang['profdeleted']           = 'A sua conta de utilizador foi removida deste wiki';
 $lang['profconfdelete']        = 'Quero remover a minha conta deste wiki. <br/> Esta ação não pode ser desfeita.';
 $lang['profconfdeletemissing'] = 'A caixa de confirmação não foi marcada';
-$lang['proffail']              = 'O perfil do usuário não foi atualizado.';
+$lang['proffail']              = 'O perfil do utilizador não foi atualizado.';
 $lang['pwdforget']             = 'Esqueceu a sua senha? Peça uma nova';
 $lang['resendna']              = 'Este wiki não suporta reenvio de senhas.';
 $lang['resendpwd']             = 'Definir nova senha para';
 $lang['resendpwdmissing']      = 'É preciso preencher todos os campos.';
-$lang['resendpwdnouser']       = 'Não foi possível encontrar este usuário.';
+$lang['resendpwdnouser']       = 'Não foi possível encontrar este utilizador.';
 $lang['resendpwdbadauth']      = 'O código de autenticação não é válido. Por favor, assegure-se de que o link de confirmação está completo.';
 $lang['resendpwdconfirm']      = 'O link de confirmação foi enviado por e-mail.';
 $lang['resendpwdsuccess']      = 'A nova senha foi enviada por e-mail.';
 $lang['license']               = 'Excepto menção em contrário, o conteúdo neste wiki está sob a seguinte licença:';
-$lang['licenseok']             = 'Nota: Ao editar esta página você aceita disponibilizar o seu conteúdo sob a seguinte licença:';
+$lang['licenseok']             = 'Nota: Ao editar esta página aceita disponibilizar o seu conteúdo sob a seguinte licença:';
 $lang['searchmedia']           = 'Procurar nome de arquivo:';
 $lang['searchmedia_in']        = 'Procurar em %s';
 $lang['txt_upload']            = 'Escolha arquivo a carregar:';
@@ -231,7 +232,7 @@ $lang['summary']               = 'Sumário da edição';
 $lang['noflash']               = 'O <a href="http://get.adobe.com/flashplayer">Plugin Adobe Flash</a> é necessário para exibir este conteúdo.';
 $lang['download']              = 'Baixar Snippet';
 $lang['tools']                 = 'Ferramentas';
-$lang['user_tools']            = 'Ferramentas de Usuário';
+$lang['user_tools']            = 'Ferramentas de Utilizador';
 $lang['site_tools']            = 'Ferramentas de Site';
 $lang['page_tools']            = 'Ferramentas de Página';
 $lang['skip_to_content']       = 'ir ao conteúdo';
@@ -239,12 +240,12 @@ $lang['sidebar']               = 'Barra Lateral';
 $lang['mail_newpage']          = 'documento adicionado:';
 $lang['mail_changed']          = 'documento modificado:';
 $lang['mail_subscribe_list']   = 'páginas alteradas no namespace:';
-$lang['mail_new_user']         = 'Novo usuário:';
+$lang['mail_new_user']         = 'Novo utilizador:';
 $lang['mail_upload']           = 'Arquivo enviado:';
 $lang['changes_type']          = 'Ver alterações de';
 $lang['pages_changes']         = 'Páginas';
-$lang['media_changes']         = 'Arquivo de mídia';
-$lang['both_changes']          = 'Tanto páginas como arquivos de mídia';
+$lang['media_changes']         = 'Arquivo de media';
+$lang['both_changes']          = 'Tanto páginas como arquivos de media';
 $lang['qb_bold']               = 'Texto Negrito';
 $lang['qb_italic']             = 'Texto Itálico';
 $lang['qb_underl']             = 'Texto Sublinhado';
@@ -287,7 +288,7 @@ $lang['img_width']             = 'Largura:';
 $lang['img_height']            = 'Altura:';
 $lang['subscr_subscribe_success'] = 'Adicionado %s à lista de subscrição para %s';
 $lang['subscr_subscribe_error'] = 'Erro ao adicionar %s à lista de subscrição para %s';
-$lang['subscr_subscribe_noaddress'] = 'Não existe endereço algum associado com o seu nome de usuário, você não pode ser adicionado à lista de subscrição';
+$lang['subscr_subscribe_noaddress'] = 'Não existe endereço algum associado com o seu nome de utilizador, não pode ser adicionado à lista de subscrição';
 $lang['subscr_unsubscribe_success'] = 'Removido %s da lista de subscrição para %s';
 $lang['subscr_unsubscribe_error'] = 'Erro ao remover %s da lista de subscrição para %s';
 $lang['subscr_already_subscribed'] = '%s já está subscrito em %s';
@@ -306,12 +307,12 @@ $lang['i_chooselang']          = 'Escolha o idioma';
 $lang['i_installer']           = 'Instalador do DokuWiki';
 $lang['i_wikiname']            = 'Nome Wiki';
 $lang['i_enableacl']           = 'Ativar ACL (recomendado)';
-$lang['i_superuser']           = 'Superusuário';
+$lang['i_superuser']           = 'Superutilizador';
 $lang['i_problems']            = 'O instalador encontrou alguns problemas, indicados abaixo. Não pode continuar até que sejam corrigidos.';
-$lang['i_modified']            = 'Por razões de segurança, este script só funciona em novas e não-modificadas instalações do Dokuwiki. Você deve re-extrair os arquivos do pacote que baixou ou então consultar as <a href="https://www.dokuwiki.org/install">instruções de instalação do Dokuwiki</a>';
-$lang['i_funcna']              = 'A função PHP <code>%s</code> não está disponível. Talvez o host a tenha desativado-a por alguma razão?';
+$lang['i_modified']            = 'Por razões de segurança, este script só funciona em novas e não-modificadas instalações do Dokuwiki. Deve re-extrair os arquivos do pacote que baixou ou então consultar as <a href="https://www.dokuwiki.org/install">instruções de instalação do Dokuwiki</a>';
+$lang['i_funcna']              = 'A função PHP <code>%s</code> não está disponível. Talvez o host a tenha desativado por alguma razão?';
 $lang['i_disabled']            = 'Isso foi desativado pelo seu provedor.';
-$lang['i_funcnmail']           = '<b>Nota:</b> A função mail do PHP não está disponível. %s Se ela permanecer indisponível, instale o <a href="https://www.dokuwiki.org/plugin:smtp">plugin smtp</a>.';
+$lang['i_funcnmail']           = '<b>Nota:</b> A função mail do PHP não está disponível. %s Se permanecer indisponível, instale o <a href="https://www.dokuwiki.org/plugin:smtp">plugin smtp</a>.';
 $lang['i_phpver']              = 'A versão de PHP actual <code>%s</code> é inferior à versão mínima <code>%s</code>. É preciso atualizar a instalação PHP.';
 $lang['i_mbfuncoverload']      = 'mbstring.func_overload deve ser desativada no php.ini para executar o DokuWiki.';
 $lang['i_urandom']             = 'DokuWiki não pode criar números criptograficamente seguros para cookies. Verifique a configuração open_basedir no php.ini para um acesso <code>/dev/urandom</code> adequado.';
@@ -320,8 +321,8 @@ $lang['i_confexists']          = '<code>%s</code> já existe';
 $lang['i_writeerr']            = 'Não foi possível criar <code>%s</code>. É preciso verificar as permissões e criar o arquivo manualmente.';
 $lang['i_badhash']             = 'dokuwiki.php não é o original ou não é reconhecido (hash=<code>%s</code>)';
 $lang['i_badval']              = '<code>%s</code> - valor ilegal ou vazio';
-$lang['i_success']             = 'A instalação e a configuração inicial terminaram. Pode remover o install.php. Acesse ao seu novo <a href="doku.php?id=wiki:welcome">Wiki</a> rodando o DokuWiki.';
-$lang['i_failure']             = 'Ocorreram alguns erros durante a escrita nos arquivos de configuração. Poderá ser preciso corrigi-los manualmente antes de poder acessar ao seu novo <a href="doku.php?id=wiki:welcome">Wiki</a> rodando o DokuWiki.';
+$lang['i_success']             = 'A instalação e a configuração inicial terminaram. Pode remover o install.php. Aceda ao seu novo <a href="doku.php?id=wiki:welcome">Wiki</a> rodando o DokuWiki.';
+$lang['i_failure']             = 'Ocorreram alguns erros durante a escrita nos arquivos de configuração. Poderá ser preciso corrigi-los manualmente antes de poder aceder ao seu novo <a href="doku.php?id=wiki:welcome">Wiki</a> rodando o DokuWiki.';
 $lang['i_policy']              = 'Política ACL inicial';
 $lang['i_pol0']                = 'Wiki Aberto (ler, escrever e enviar arquivos para todos)';
 $lang['i_pol1']                = 'Wiki Público (ler para todos, escrever e enviar arquivos para utilizadores inscritos)';
@@ -331,8 +332,8 @@ $lang['i_retry']               = 'Repetir';
 $lang['i_license']             = 'Por favor escolha a licença sob a qual quer colocar o seu conteúdo:';
 $lang['i_license_none']        = 'Não mostrar nenhuma informação de licença';
 $lang['i_pop_field']           = 'Por favor ajude-nos a melhorar a experiência Dokuwiki:';
-$lang['i_pop_label']           = 'Uma vez por mês, enviar dados anônimos de uso para os desenvolvedores DokuWiki';
-$lang['recent_global']         = 'Você está vendo as alterações dentro do namespace <b>%s</b>. Também é possível ver as <a href="%s">modificações recentes no wiki inteiro</a>.';
+$lang['i_pop_label']           = 'Uma vez por mês, enviar dados anónimos de uso para os desenvolvedores DokuWiki';
+$lang['recent_global']         = 'Está a ver as alterações dentro do namespace <b>%s</b>. Também é possível ver as <a href="%s">modificações recentes no wiki inteiro</a>.';
 $lang['years']                 = '%d anos atrás';
 $lang['months']                = '%d meses atrás';
 $lang['weeks']                 = '%d semanas atrás';
