@@ -3,8 +3,8 @@
 /**
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
  *
- * @author Nikita <obraztsov568@gmail.com>
  * @author Aleksandr Selivanov <alexgearbox@yandex.ru>
+ * @author Nikita <obraztsov568@gmail.com>
  * @author Анатолий <anatol_m@mail.ru>
  * @author Yuriy Skalko <yuriy.skalko@gmail.com>
  * @author Alexander Kh. <001.arx@gmail.com>
@@ -199,7 +199,7 @@ $lang['lockedby']              = 'В данный момент заблокир
 $lang['lockexpire']            = 'Блокировка истекает в';
 $lang['rssfailed']             = 'Произошла ошибка при получении новостной ленты: ';
 $lang['nothingfound']          = 'Ничего не найдено.';
-$lang['mediaselect']           = 'Выбор медиафайла';
+$lang['mediaselect']           = 'Медиафайлы';
 $lang['uploadsucc']            = 'Загрузка произведена успешно';
 $lang['uploadfail']            = 'Загрузка не удалась. Возможно, проблемы с правами доступа?';
 $lang['uploadwrong']           = 'В загрузке отказано. Файлы с таким расширением запрещены!';
@@ -248,6 +248,7 @@ $lang['created']               = 'создано';
 $lang['restored']              = 'старая версия восстановлена (%s)';
 $lang['external_edit']         = 'внешнее изменение';
 $lang['summary']               = 'Сводка изменений';
+$lang['unknowndate']           = 'Дата неизвестна';
 $lang['noflash']               = 'Для просмотра этого содержимого требуется <a href="http://get.adobe.com/flashplayer">Adobe Flash Plugin</a>.';
 $lang['download']              = 'Скачать фрагмент кода';
 $lang['tools']                 = 'Инструменты';
@@ -268,7 +269,7 @@ $lang['both_changes']          = 'и страниц, и медиафайлов';
 $lang['qb_bold']               = 'Полужирный';
 $lang['qb_italic']             = 'Курсив';
 $lang['qb_underl']             = 'Подчёркнутый';
-$lang['qb_code']               = 'Текст кода';
+$lang['qb_code']               = 'Моноширинный';
 $lang['qb_strike']             = 'Зачёркнутый';
 $lang['qb_h1']                 = 'Заголовок 1-го уровня';
 $lang['qb_h2']                 = 'Заголовок 2-го уровня';
@@ -330,19 +331,19 @@ $lang['i_superuser']           = 'Суперпользователь';
 $lang['i_problems']            = 'Программа установки столкнулась с проблемами, перечисленными ниже. Чтобы продолжить, вам необходимо их устранить. ';
 $lang['i_modified']            = 'Из соображений безопасности эта программа запускается только на новой, неизменённой установке «Докувики».
                                   Вам нужно либо заново распаковать скачанный пакет установки, либо обратиться к полной
-                                  <a href="http://www.dokuwiki.org/install">инструкции по установке «Докувики»</a>';
+                                  <a href="https://www.dokuwiki.org/install">инструкции по установке «Докувики»</a>';
 $lang['i_funcna']              = 'Функция PHP <code>%s</code> недоступна. Может быть, она по какой-то причине заблокирована вашим хостером?';
 $lang['i_disabled']            = 'Отключено вашим провайдером.';
 $lang['i_funcnmail']           = '<b>Примечание:</ b> PHP-функция mail недоступна. %s Если она по прежнему недоступна, вы можете установить <a href="https://www.dokuwiki.org/plugin:smtp">плагин SMTP</a>.';
 $lang['i_phpver']              = 'Ваша версия PHP (<code>%s</code>) ниже требуемой (<code>%s</code>). Вам необходимо обновить установленную версию PHP.';
 $lang['i_mbfuncoverload']      = 'Для запуска «Докувики» необходимо отключить параметр mbstring.func_overload в php.ini';
-$lang['i_urandom']             = 'DokuWiki не может создавать криптографически безопасные номера для файлов cookie. Возможно, вы захотите проверить настройки open_basedir в php.ini для правильного доступа <code> / dev / urandom </ code>.';
+$lang['i_urandom']             = '«Докувики» не может создавать криптографически безопасные номера для файлов cookie. Возможно, вы захотите проверить настройки open_basedir в php.ini для правильного доступа <code>/dev/urandom</ code>.';
 $lang['i_permfail']            = '<code>%s</code> недоступна для записи «Докувики». Вам необходимо исправить системные права доступа для этой директории!';
 $lang['i_confexists']          = '<code>%s</code> уже существует';
 $lang['i_writeerr']            = 'Не удалось создать <code>%s</code>. Вам необходимо проверить системные права доступа к файлу и директориям, и создать файл вручную.';
 $lang['i_badhash']             = 'dokuwiki.php не распознан или изменён (hash=<code>%s</code>)';
 $lang['i_badval']              = '<code>%s</code> — недопустимое или пустое значение';
-$lang['i_success']             = 'Конфигурация прошла успешно. Теперь вы можете удалить файл install.php. Переходите к
+$lang['i_success']             = 'Настройка прошла успешно. Теперь вы можете удалить файл install.php. Переходите к
                                  <a href="doku.php?id=wiki:welcome">своей новой «Докувики»</a>.';
 $lang['i_failure']             = 'При записи в файлы конфигурации были обнаружены ошибки. Возможно, вам придётся исправить их вручную, прежде чем вы сможете использовать <a href="doku.php?id=wiki:welcome">свою новую «Докувики»</a>.';
 $lang['i_policy']              = 'Исходная политика прав доступа';
