@@ -1,6 +1,8 @@
 <?php
 
 use dokuwiki\ChangeLog\MediaChangeLog;
+use dokuwiki\File\MediaResolver;
+use dokuwiki\File\PageResolver;
 
 /**
  * Renderer for XHTML output
@@ -18,9 +20,6 @@ class Doku_Renderer_xhtml extends Doku_Renderer {
     /** @var array A stack of section edit data */
     protected $sectionedits = array();
 
-    /** @var string|int link pages and media against this revision */
-    public $date_at = '';
-
     /** @var int last section edit id, used by startSectionEdit */
     protected $lastsecid = 0;
 
@@ -93,6 +92,9 @@ class Doku_Renderer_xhtml extends Doku_Renderer {
      * @author Adrian Lang <lang@cosmocode.de>
      */
     public function finishSectionEdit($end = null, $hid = null) {
+        if(count($this->sectionedits) == 0) {
+            return;
+        }
         $data = array_pop($this->sectionedits);
         if(!is_null($end) && $end <= $data['start']) {
             return;
@@ -202,11 +204,13 @@ class Doku_Renderer_xhtml extends Doku_Renderer {
     /**
      * Render a heading
      *
-     * @param string $text  the text to display
-     * @param int    $level header level
-     * @param int    $pos   byte position in the original source
+     * @param string $text       the text to display
+     * @param int    $level      header level
+     * @param int    $pos        byte position in the original source
+     * @param bool   $returnonly whether to return html or write to doc attribute
+     * @return void|string writes to doc attribute or returns html depends on $returnonly
      */
-    public function header($text, $level, $pos) {
+    public function header($text, $level, $pos, $returnonly = false) {
         global $conf;
 
         if(blank($text)) return; //skip empty headlines
@@ -232,19 +236,25 @@ class Doku_Renderer_xhtml extends Doku_Renderer {
             $this->finishSectionEdit($pos - 1);
         }
 
-        // write the header
-        $this->doc .= DOKU_LF.'<h'.$level;
+        // build the header
+        $header = DOKU_LF.'<h'.$level;
         if($level <= $conf['maxseclevel']) {
             $data = array();
             $data['target'] = 'section';
             $data['name'] = $text;
             $data['hid'] = $hid;
             $data['codeblockOffset'] = $this->_codeblock;
-            $this->doc .= ' class="'.$this->startSectionEdit($pos, $data).'"';
+            $header .= ' class="'.$this->startSectionEdit($pos, $data).'"';
+        }
+        $header .= ' id="'.$hid.'">';
+        $header .= $this->_xmlEntities($text);
+        $header .= "</h$level>".DOKU_LF;
+
+        if ($returnonly) {
+            return $header;
+        } else {
+            $this->doc .= $header;
         }
-        $this->doc .= ' id="'.$hid.'">';
-        $this->doc .= $this->_xmlEntities($text);
-        $this->doc .= "</h$level>".DOKU_LF;
     }
 
     /**
@@ -533,68 +543,6 @@ class Doku_Renderer_xhtml extends Doku_Renderer {
         $this->doc .= $this->_xmlEntities($text);
     }
 
-    /**
-     * Execute PHP code if allowed
-     *
-     * @param  string $text      PHP code that is either executed or printed
-     * @param  string $wrapper   html element to wrap result if $conf['phpok'] is okff
-     *
-     * @author Andreas Gohr <andi@splitbrain.org>
-     */
-    public function php($text, $wrapper = 'code') {
-        global $conf;
-
-        if($conf['phpok']) {
-            ob_start();
-            eval($text);
-            $this->doc .= ob_get_contents();
-            ob_end_clean();
-        } else {
-            $this->doc .= p_xhtml_cached_geshi($text, 'php', $wrapper);
-        }
-    }
-
-    /**
-     * Output block level PHP code
-     *
-     * If $conf['phpok'] is true this should evaluate the given code and append the result
-     * to $doc
-     *
-     * @param string $text The PHP code
-     */
-    public function phpblock($text) {
-        $this->php($text, 'pre');
-    }
-
-    /**
-     * Insert HTML if allowed
-     *
-     * @param  string $text      html text
-     * @param  string $wrapper   html element to wrap result if $conf['htmlok'] is okff
-     *
-     * @author Andreas Gohr <andi@splitbrain.org>
-     */
-    public function html($text, $wrapper = 'code') {
-        global $conf;
-
-        if($conf['htmlok']) {
-            $this->doc .= $text;
-        } else {
-            $this->doc .= p_xhtml_cached_geshi($text, 'html4strict', $wrapper);
-        }
-    }
-
-    /**
-     * Output raw block-level HTML
-     *
-     * If $conf['htmlok'] is true this should add the code as is to $doc
-     *
-     * @param string $text The HTML
-     */
-    public function htmlblock($text) {
-        $this->html($text, 'pre');
-    }
-
     /**
      * Start a block quote
      */
@@ -657,9 +605,7 @@ class Doku_Renderer_xhtml extends Doku_Renderer {
         global $lang;
         global $INPUT;
 
-        $language = preg_replace(PREG_PATTERN_VALID_LANGUAGE, '', $language);
-
-        $language = preg_replace(PREG_PATTERN_VALID_LANGUAGE, '', $language);
+        $language = preg_replace(PREG_PATTERN_VALID_LANGUAGE, '', $language ?? '');
 
         if($filename) {
             // add icon
@@ -736,10 +682,9 @@ class Doku_Renderer_xhtml extends Doku_Renderer {
      * @param string $smiley
      */
     public function smiley($smiley) {
-        if(array_key_exists($smiley, $this->smileys)) {
-            $this->doc .= '<img src="'.DOKU_BASE.'lib/images/smileys/'.$this->smileys[$smiley].
-                '" class="icon" alt="'.
-                $this->_xmlEntities($smiley).'" />';
+        if (isset($this->smileys[$smiley])) {
+            $this->doc .= '<img src="' . DOKU_BASE . 'lib/images/smileys/' . $this->smileys[$smiley] .
+                '" class="icon smiley" alt="' . $this->_xmlEntities($smiley) . '" />';
         } else {
             $this->doc .= $this->_xmlEntities($smiley);
         }
@@ -894,7 +839,8 @@ class Doku_Renderer_xhtml extends Doku_Renderer {
         $default = $this->_simpleTitle($id);
 
         // now first resolve and clean up the $id
-        resolve_pageid(getNS($ID), $id, $exists, $this->date_at, true);
+        $id = (new PageResolver($ID))->resolveId($id, $this->date_at, true);
+        $exists = page_exists($id, $this->date_at, false, true);
 
         $link = array();
         $name = $this->_getLinkTitle($name, $default, $isImage, $id, $linktype);
@@ -910,7 +856,7 @@ class Doku_Renderer_xhtml extends Doku_Renderer {
         }
 
         //keep hash anchor
-        @list($id, $hash) = explode('#', $id, 2);
+        list($id, $hash) = sexplode('#', $id, 2);
         if(!empty($hash)) $hash = $this->_headerToLink($hash);
 
         //prepare for formating
@@ -1057,7 +1003,7 @@ class Doku_Renderer_xhtml extends Doku_Renderer {
         if($conf['target']['interwiki']) $link['rel'] .= ' noopener';
 
         $link['url']   = $url;
-        $link['title'] = htmlspecialchars($link['url']);
+        $link['title'] = $this->_xmlEntities($link['url']);
 
         // output formatted
         if($returnonly) {
@@ -1173,9 +1119,10 @@ class Doku_Renderer_xhtml extends Doku_Renderer {
                            $height = null, $cache = null, $linking = null, $return = false) {
         global $ID;
         if (strpos($src, '#') !== false) {
-            list($src, $hash) = explode('#', $src, 2);
+            list($src, $hash) = sexplode('#', $src, 2);
         }
-        resolve_mediaid(getNS($ID), $src, $exists, $this->date_at, true);
+        $src = (new MediaResolver($ID))->resolveId($src,$this->date_at,true);
+        $exists = media_exists($src);
 
         $noLink = false;
         $render = ($linking == 'linkonly') ? false : true;
@@ -1244,7 +1191,7 @@ class Doku_Renderer_xhtml extends Doku_Renderer {
     public function externalmedia($src, $title = null, $align = null, $width = null,
                            $height = null, $cache = null, $linking = null, $return = false) {
         if(link_isinterwiki($src)){
-            list($shortcut, $reference) = explode('>', $src, 2);
+            list($shortcut, $reference) = sexplode('>', $src, 2, '');
             $exists = null;
             $src = $this->_resolveInterWiki($shortcut, $reference, $exists);
             if($src == '' && empty($title)){
@@ -1252,7 +1199,7 @@ class Doku_Renderer_xhtml extends Doku_Renderer {
                 $title = $reference;
             }
         }
-        list($src, $hash) = explode('#', $src, 2);
+        list($src, $hash) = sexplode('#', $src, 2);
         $noLink = false;
         if($src == '') {
             // only output plaintext without link if there is no src
@@ -1358,11 +1305,7 @@ class Doku_Renderer_xhtml extends Doku_Renderer {
                 }
                 if($params['details']) {
                     $this->doc .= '<div class="detail">';
-                    if($conf['htmlok']) {
-                        $this->doc .= $item->get_description();
-                    } else {
-                        $this->doc .= strip_tags($item->get_description());
-                    }
+                    $this->doc .= strip_tags($item->get_description());
                     $this->doc .= '</div>';
                 }
 
@@ -1660,6 +1603,7 @@ class Doku_Renderer_xhtml extends Doku_Renderer {
                     )
                 ) . '"';
             $ret .= ' class="media'.$align.'"';
+            $ret .= ' loading="lazy"';
 
             if($title) {
                 $ret .= ' title="'.$title.'"';
@@ -1740,7 +1684,7 @@ class Doku_Renderer_xhtml extends Doku_Renderer {
      * @return string
      */
     public function _xmlEntities($string) {
-        return htmlspecialchars($string, ENT_QUOTES, 'UTF-8');
+        return hsc($string);
     }
 
 
@@ -1788,7 +1732,7 @@ class Doku_Renderer_xhtml extends Doku_Renderer {
         // see internalmedia() and externalmedia()
         list($img['src']) = explode('#', $img['src'], 2);
         if($img['type'] == 'internalmedia') {
-            resolve_mediaid(getNS($ID), $img['src'], $exists ,$this->date_at, true);
+            $img['src'] = (new MediaResolver($ID))->resolveId($img['src'], $this->date_at, true);
         }
 
         return $this->_media(
@@ -1889,7 +1833,9 @@ class Doku_Renderer_xhtml extends Doku_Renderer {
                 $url = ml($file, '', true, '&');
                 $linkType = 'internalmedia';
             }
-            $title = $atts['title'] ? $atts['title'] : $this->_xmlEntities(\dokuwiki\Utf8\PhpString::basename(noNS($file)));
+            $title = !empty($atts['title'])
+                ? $atts['title']
+                : $this->_xmlEntities(\dokuwiki\Utf8\PhpString::basename(noNS($file)));
 
             $out .= '<source src="'.hsc($url).'" type="'.$mime.'" />'.NL;
             // alternative content (just a link to the file)
@@ -1987,10 +1933,10 @@ class Doku_Renderer_xhtml extends Doku_Renderer {
      * @access protected
      * @return string revision ('' for current)
      */
-    protected function _getLastMediaRevisionAt($media_id){
-        if(!$this->date_at || media_isexternal($media_id)) return '';
-        $pagelog = new MediaChangeLog($media_id);
-        return $pagelog->getLastRevisionAt($this->date_at);
+    protected function _getLastMediaRevisionAt($media_id) {
+        if (!$this->date_at || media_isexternal($media_id)) return '';
+        $changelog = new MediaChangeLog($media_id);
+        return $changelog->getLastRevisionAt($this->date_at);
     }
 
     #endregion
