@@ -388,12 +388,12 @@ function _tpl_metaheaders_action($data) {
             if ( empty($attr) ) { continue; }
             echo '<', $tag, ' ', buildAttributes($attr);
             if(isset($attr['_data']) || $tag == 'script') {
-                if($tag == 'script' && $attr['_data'])
+                if($tag == 'script' && isset($attr['_data']))
                     $attr['_data'] = "/*<![CDATA[*/".
                         $attr['_data'].
                         "\n/*!]]>*/";
 
-                echo '>', $attr['_data'], '</', $tag, '>';
+                echo '>', isset($attr['_data']) ? $attr['_data'] : '', '</', $tag, '>';
             } else {
                 echo '/>';
             }
@@ -1009,20 +1009,27 @@ function tpl_pagetitle($id = null, $ret = false) {
  */
 function tpl_img_getTag($tags, $alt = '', $src = null) {
     // Init Exif Reader
-    global $SRC;
+    global $SRC, $imgMeta;
 
     if(is_null($src)) $src = $SRC;
     if(is_null($src)) return $alt;
 
-    static $meta = null;
-    if(is_null($meta)) $meta = new JpegMeta($src);
-    if($meta === false) return $alt;
-    $info = cleanText($meta->getField($tags));
-    $meta = null; // garbage collect and close any file handles. See #3404
+    if(!isset($imgMeta) || $imgMeta === null) $imgMeta = new JpegMeta($src);
+    if($imgMeta === false) return $alt;
+    $info = cleanText($imgMeta->getField($tags));
     if($info == false) return $alt;
     return $info;
 }
 
+
+/**
+ * Garbage collects up the open JpegMeta object.
+ */
+function tpl_img_close(){
+    global $imgMeta;
+    $imgMeta = null;
+}
+
 /**
  * Returns a description list of the metatags of the current image
  *
@@ -1802,7 +1809,7 @@ function tpl_classes() {
         'mode_'.$ACT,
         'tpl_'.$conf['template'],
         $INPUT->server->bool('REMOTE_USER') ? 'loggedIn' : '',
-        (isset($INFO) && $INFO['exists']) ? '' : 'notFound',
+        (isset($INFO['exists']) && $INFO['exists']) ? '' : 'notFound',
         ($ID == $conf['start']) ? 'home' : '',
     );
     return join(' ', $classes);
