@@ -6,7 +6,10 @@
  * @author     Andreas Gohr <andi@splitbrain.org>
  */
 
-if(!defined('DOKU_INC')) define('DOKU_INC',dirname(__FILE__).'/../../');
+use dokuwiki\Cache\Cache;
+use dokuwiki\Extension\Event;
+
+if(!defined('DOKU_INC')) define('DOKU_INC', __DIR__ .'/../../');
 if(!defined('NOSESSION')) define('NOSESSION',true); // we do not use a session or authentication here (better caching)
 if(!defined('DOKU_DISABLE_GZIP_OUTPUT')) define('DOKU_DISABLE_GZIP_OUTPUT',1); // we gzip ourself here
 if(!defined('NL')) define('NL',"\n");
@@ -36,7 +39,7 @@ function css_out(){
         $mediatypes = array('feed');
         $type = 'feed';
     } else {
-        $mediatypes = array('screen', 'all', 'print');
+        $mediatypes = array('screen', 'all', 'print', 'speech');
         $type = '';
     }
 
@@ -44,16 +47,9 @@ function css_out(){
     $tpl = trim(preg_replace('/[^\w-]+/','',$INPUT->str('t')));
     if(!$tpl) $tpl = $conf['template'];
 
-    // The generated script depends on some dynamic options
-    $cache = new cache('styles'.$_SERVER['HTTP_HOST'].$_SERVER['SERVER_PORT'].$INPUT->int('preview').DOKU_BASE.$tpl.$type,'.css');
-
-    // load styl.ini
-    $styleini = css_styleini($tpl, $INPUT->bool('preview'));
-
-    // if old 'default' userstyle setting exists, make it 'screen' userstyle for backwards compatibility
-    if (isset($config_cascade['userstyle']['default'])) {
-        $config_cascade['userstyle']['screen'] = array($config_cascade['userstyle']['default']);
-    }
+    // load style.ini
+    $styleUtil = new \dokuwiki\StyleUtils($tpl, $INPUT->bool('preview'));
+    $styleini = $styleUtil->cssStyleini();
 
     // cache influencers
     $tplinc = tpl_incdir($tpl);
@@ -65,72 +61,102 @@ function css_out(){
 
     // Array of needed files and their web locations, the latter ones
     // are needed to fix relative paths in the stylesheets
-    $files = array();
+    $media_files = array();
     foreach($mediatypes as $mediatype) {
-        $files[$mediatype] = array();
+        $files = array();
+
         // load core styles
-        $files[$mediatype][DOKU_INC.'lib/styles/'.$mediatype.'.css'] = DOKU_BASE.'lib/styles/';
+        $files[DOKU_INC.'lib/styles/'.$mediatype.'.css'] = DOKU_BASE.'lib/styles/';
 
         // load jQuery-UI theme
         if ($mediatype == 'screen') {
-            $files[$mediatype][DOKU_INC.'lib/scripts/jquery/jquery-ui-theme/smoothness.css'] = DOKU_BASE.'lib/scripts/jquery/jquery-ui-theme/';
+            $files[DOKU_INC.'lib/scripts/jquery/jquery-ui-theme/smoothness.css'] =
+                DOKU_BASE.'lib/scripts/jquery/jquery-ui-theme/';
         }
         // load plugin styles
-        $files[$mediatype] = array_merge($files[$mediatype], css_pluginstyles($mediatype));
+        $files = array_merge($files, css_pluginstyles($mediatype));
         // load template styles
         if (isset($styleini['stylesheets'][$mediatype])) {
-            $files[$mediatype] = array_merge($files[$mediatype], $styleini['stylesheets'][$mediatype]);
+            $files = array_merge($files, $styleini['stylesheets'][$mediatype]);
         }
         // load user styles
-        if(!empty($config_cascade['userstyle'][$mediatype])) {
+        if(isset($config_cascade['userstyle'][$mediatype]) and is_array($config_cascade['userstyle'][$mediatype])) {
             foreach($config_cascade['userstyle'][$mediatype] as $userstyle) {
-                $files[$mediatype][$userstyle] = DOKU_BASE;
+                $files[$userstyle] = DOKU_BASE;
             }
         }
 
-        $cache_files = array_merge($cache_files, array_keys($files[$mediatype]));
+        // Let plugins decide to either put more styles here or to remove some
+        $media_files[$mediatype] = css_filewrapper($mediatype, $files);
+        $CSSEvt = new Event('CSS_STYLES_INCLUDED', $media_files[$mediatype]);
+
+        // Make it preventable.
+        if ( $CSSEvt->advise_before() ) {
+            $cache_files = array_merge($cache_files, array_keys($media_files[$mediatype]['files']));
+        } else {
+            // unset if prevented. Nothing will be printed for this mediatype.
+            unset($media_files[$mediatype]);
+        }
+
+        // finish event.
+        $CSSEvt->advise_after();
     }
 
+    // The generated script depends on some dynamic options
+    $cache = new Cache(
+        'styles' .
+        $_SERVER['HTTP_HOST'] .
+        $_SERVER['SERVER_PORT'] .
+        $INPUT->bool('preview') .
+        DOKU_BASE .
+        $tpl .
+        $type,
+        '.css'
+    );
+    $cache->setEvent('CSS_CACHE_USE');
+
     // check cache age & handle conditional request
     // This may exit if a cache can be used
-    http_cached($cache->cache,
-                $cache->useCache(array('files' => $cache_files)));
+    $cache_ok = $cache->useCache(array('files' => $cache_files));
+    http_cached($cache->cache, $cache_ok);
 
     // start output buffering
     ob_start();
 
+    // Fire CSS_STYLES_INCLUDED for one last time to let the
+    // plugins decide whether to include the DW default styles.
+    // This can be done by preventing the Default.
+    $media_files['DW_DEFAULT'] = css_filewrapper('DW_DEFAULT');
+    Event::createAndTrigger('CSS_STYLES_INCLUDED', $media_files['DW_DEFAULT'], 'css_defaultstyles');
+
     // build the stylesheet
     foreach ($mediatypes as $mediatype) {
 
-        // print the default classes for interwiki links and file downloads
-        if ($mediatype == 'screen') {
-            print '@media screen {';
-            css_interwiki();
-            css_filetypes();
-            print '}';
+        // Check if there is a wrapper set for this type.
+        if ( !isset($media_files[$mediatype]) ) {
+            continue;
         }
 
+        $cssData = $media_files[$mediatype];
+
+        // Print the styles.
+        print NL;
+        if ( $cssData['encapsulate'] === true ) print $cssData['encapsulationPrefix'] . ' {';
+        print '/* START '.$cssData['mediatype'].' styles */'.NL;
+
         // load files
-        $css_content = '';
-        foreach($files[$mediatype] as $file => $location){
+        foreach($cssData['files'] as $file => $location){
             $display = str_replace(fullpath(DOKU_INC), '', fullpath($file));
-            $css_content .= "\n/* XXXXXXXXX $display XXXXXXXXX */\n";
-            $css_content .= css_loadfile($file, $location);
-        }
-        switch ($mediatype) {
-            case 'screen':
-                print NL.'@media screen { /* START screen styles */'.NL.$css_content.NL.'} /* /@media END screen styles */'.NL;
-                break;
-            case 'print':
-                print NL.'@media print { /* START print styles */'.NL.$css_content.NL.'} /* /@media END print styles */'.NL;
-                break;
-            case 'all':
-            case 'feed':
-            default:
-                print NL.'/* START rest styles */ '.NL.$css_content.NL.'/* END rest styles */'.NL;
-                break;
+            print "\n/* XXXXXXXXX $display XXXXXXXXX */\n";
+            print css_loadfile($file, $location);
         }
+
+        print NL;
+        if ( $cssData['encapsulate'] === true ) print '} /* /@media ';
+        else print '/*';
+        print ' END '.$cssData['mediatype'].' styles */'.NL;
     }
+
     // end output buffering and get contents
     $css = ob_get_contents();
     ob_end_clean();
@@ -171,7 +197,7 @@ function css_parseless($css) {
     global $conf;
 
     $less = new lessc();
-    $less->importDir[] = DOKU_INC;
+    $less->importDir = array(DOKU_INC);
     $less->setPreserveComments(!$conf['compress']);
 
     if (defined('DOKU_UNITTEST')){
@@ -253,92 +279,38 @@ function css_applystyle($css, $replacements) {
 }
 
 /**
- * Load style ini contents
+ * Wrapper for the files, content and mediatype for the event CSS_STYLES_INCLUDED
  *
- * Loads and merges style.ini files from template and config and prepares
- * the stylesheet modes
+ * @author Gerry Weißbach <gerry.w@gammaproduction.de>
  *
- * @author Andreas Gohr <andi@splitbrain.org>
- *
- * @param string $tpl the used template
- * @param bool   $preview load preview replacements
- * @return array with keys 'stylesheets' and 'replacements'
+ * @param string $mediatype type ofthe current media files/content set
+ * @param array $files set of files that define the current mediatype
+ * @return array
  */
-function css_styleini($tpl, $preview=false) {
-    global $conf;
-
-    $stylesheets = array(); // mode, file => base
-    $replacements = array(); // placeholder => value
-
-    // load template's style.ini
-    $incbase = tpl_incdir($tpl);
-    $webbase = tpl_basedir($tpl);
-    $ini = $incbase.'style.ini';
-    if(file_exists($ini)){
-        $data = parse_ini_file($ini, true);
-
-        // stylesheets
-        if(is_array($data['stylesheets'])) foreach($data['stylesheets'] as $file => $mode){
-            $stylesheets[$mode][$incbase.$file] = $webbase;
-        }
-
-        // replacements
-        if(is_array($data['replacements'])){
-            $replacements = array_merge($replacements, css_fixreplacementurls($data['replacements'],$webbase));
-        }
-    }
-
-    // load configs's style.ini
-    $webbase = DOKU_BASE;
-    $ini = DOKU_CONF."tpl/$tpl/style.ini";
-    $incbase = dirname($ini).'/';
-    if(file_exists($ini)){
-        $data = parse_ini_file($ini, true);
-
-        // stylesheets
-        if(is_array($data['stylesheets'])) foreach($data['stylesheets'] as $file => $mode){
-            $stylesheets[$mode][$incbase.$file] = $webbase;
-        }
-
-        // replacements
-        if(is_array($data['replacements'])){
-            $replacements = array_merge($replacements, css_fixreplacementurls($data['replacements'],$webbase));
-        }
-    }
-
-    // allow replacement overwrites in preview mode
-    if($preview) {
-        $webbase = DOKU_BASE;
-        $ini     = $conf['cachedir'].'/preview.ini';
-        if(file_exists($ini)) {
-            $data = parse_ini_file($ini, true);
-            // replacements
-            if(is_array($data['replacements'])) {
-                $replacements = array_merge($replacements, css_fixreplacementurls($data['replacements'], $webbase));
-            }
-        }
-    }
-
+function css_filewrapper($mediatype, $files=array()){
     return array(
-        'stylesheets' => $stylesheets,
-        'replacements' => $replacements
-    );
+            'files'                 => $files,
+            'mediatype'             => $mediatype,
+            'encapsulate'           => $mediatype != 'all',
+            'encapsulationPrefix'   => '@media '.$mediatype
+        );
 }
 
 /**
- * Amend paths used in replacement relative urls, refer FS#2879
+ * Prints the @media encapsulated default styles of DokuWiki
  *
- * @author Chris Smith <chris@jalakai.co.uk>
+ * @author Gerry Weißbach <gerry.w@gammaproduction.de>
  *
- * @param array $replacements with key-value pairs
- * @param string $location
- * @return array
+ * This function is being called by a CSS_STYLES_INCLUDED event
+ * The event can be distinguished by the mediatype which is:
+ *   DW_DEFAULT
  */
-function css_fixreplacementurls($replacements, $location) {
-    foreach($replacements as $key => $value) {
-        $replacements[$key] = preg_replace('#(url\([ \'"]*)(?!/|data:|http://|https://| |\'|")#','\\1'.$location,$value);
-    }
-    return $replacements;
+function css_defaultstyles(){
+    // print the default classes for interwiki links and file downloads
+    print '@media screen {';
+    css_interwiki();
+    css_filetypes();
+    print '}';
 }
 
 /**
@@ -356,22 +328,24 @@ function css_interwiki(){
 
     // default style
     echo 'a.interwiki {';
-    echo ' background: transparent url('.DOKU_BASE.'lib/images/interwiki.png) 0px 1px no-repeat;';
-    echo ' padding: 1px 0px 1px 16px;';
+    echo ' background: transparent url('.DOKU_BASE.'lib/images/interwiki.svg) 0 0 no-repeat;';
+    echo ' background-size: 1.2em;';
+    echo ' padding: 0 0 0 1.4em;';
     echo '}';
 
     // additional styles when icon available
     $iwlinks = getInterwiki();
-    foreach(array_keys($iwlinks) as $iw){
-        $class = preg_replace('/[^_\-a-z0-9]+/i','_',$iw);
-        if(file_exists(DOKU_INC.'lib/images/interwiki/'.$iw.'.png')){
-            echo "a.iw_$class {";
-            echo '  background-image: url('.DOKU_BASE.'lib/images/interwiki/'.$iw.'.png)';
-            echo '}';
-        }elseif(file_exists(DOKU_INC.'lib/images/interwiki/'.$iw.'.gif')){
-            echo "a.iw_$class {";
-            echo '  background-image: url('.DOKU_BASE.'lib/images/interwiki/'.$iw.'.gif)';
-            echo '}';
+    foreach (array_keys($iwlinks) as $iw) {
+        $class = preg_replace('/[^_\-a-z0-9]+/i', '_', $iw);
+        foreach (['svg', 'png', 'gif'] as $ext) {
+            $file = 'lib/images/interwiki/' . $iw . '.' . $ext;
+
+            if (file_exists(DOKU_INC . $file)) {
+                echo "a.iw_$class {";
+                echo '  background-image: url(' . DOKU_BASE . $file . ')';
+                echo '}';
+                break;
+            }
         }
     }
 }
@@ -385,30 +359,26 @@ function css_filetypes(){
 
     // default style
     echo '.mediafile {';
-    echo ' background: transparent url('.DOKU_BASE.'lib/images/fileicons/file.png) 0px 1px no-repeat;';
-    echo ' padding-left: 18px;';
-    echo ' padding-bottom: 1px;';
+    echo ' background: transparent url('.DOKU_BASE.'lib/images/fileicons/svg/file.svg) 0px 1px no-repeat;';
+    echo ' background-size: 1.2em;';
+    echo ' padding-left: 1.5em;';
     echo '}';
 
     // additional styles when icon available
     // scan directory for all icons
     $exts = array();
-    if($dh = opendir(DOKU_INC.'lib/images/fileicons')){
+    if($dh = opendir(DOKU_INC.'lib/images/fileicons/svg')){
         while(false !== ($file = readdir($dh))){
-            if(preg_match('/([_\-a-z0-9]+(?:\.[_\-a-z0-9]+)*?)\.(png|gif)/i',$file,$match)){
-                $ext = strtolower($match[1]);
-                $type = '.'.strtolower($match[2]);
-                if($ext!='file' && (!isset($exts[$ext]) || $type=='.png')){
-                    $exts[$ext] = $type;
-                }
+            if(preg_match('/(.*?)\.svg$/i',$file, $match)){
+                $exts[] = strtolower($match[1]);
             }
         }
         closedir($dh);
     }
-    foreach($exts as $ext=>$type){
+    foreach($exts as $ext){
         $class = preg_replace('/[^_\-a-z0-9]+/','_',$ext);
         echo ".mf_$class {";
-        echo '  background-image: url('.DOKU_BASE.'lib/images/fileicons/'.$ext.$type.')';
+        echo '  background-image: url('.DOKU_BASE.'lib/images/fileicons/svg/'.$ext.'.svg)';
         echo '}';
     }
 }
@@ -495,18 +465,13 @@ class DokuCssFile {
      */
     public function replacements($match) {
 
-        // not a relative url? - no adjustment required
-        if (preg_match('#^(/|data:|https?://)#',$match[3])) {
+        if (preg_match('#^(/|data:|https?://)#', $match[3])) { // not a relative url? - no adjustment required
             return $match[0];
-        }
-        // a less file import? - requires a file system location
-        else if (substr($match[3],-5) == '.less') {
-            if ($match[3]{0} != '/') {
+        } elseif (substr($match[3], -5) == '.less') { // a less file import? - requires a file system location
+            if ($match[3][0] != '/') {
                 $match[3] = $this->getRelativePath() . '/' . $match[3];
             }
-        }
-        // everything else requires a url adjustment
-        else {
+        } else { // everything else requires a url adjustment
             $match[3] = $this->location . $match[3];
         }
 
@@ -535,7 +500,7 @@ function css_datauri($match){
     if($size && $size < $conf['cssdatauri']){
         $data = base64_encode(file_get_contents($local));
     }
-    if($data){
+    if (!empty($data)){
         $url = 'data:image/'.$ext.';base64,'.$data;
     }else{
         $url = $base.$url;
@@ -576,10 +541,20 @@ function css_pluginstyles($mediatype='screen'){
  * @return string
  */
 function css_compress($css){
-    //strip comments through a callback
+    // replace quoted strings with placeholder
+    $quote_storage = [];
+
+    $quote_cb = function ($match) use (&$quote_storage) {
+        $quote_storage[] = $match[0];
+        return '"STR'.(count($quote_storage)-1).'"';
+    };
+
+    $css = preg_replace_callback('/(([\'"]).*?(?<!\\\\)\2)/', $quote_cb, $css);
+
+    // strip comments through a callback
     $css = preg_replace_callback('#(/\*)(.*?)(\*/)#s','css_comment_cb',$css);
 
-    //strip (incorrect but common) one line comments
+    // strip (incorrect but common) one line comments
     $css = preg_replace_callback('/^.*\/\/.*$/m','css_onelinecomment_cb',$css);
 
     // strip whitespaces
@@ -588,18 +563,58 @@ function css_compress($css){
     $css = preg_replace('/ ?: /',':',$css);
 
     // number compression
-    $css = preg_replace('/([: ])0+(\.\d+?)0*((?:pt|pc|in|mm|cm|em|ex|px)\b|%)(?=[^\{]*[;\}])/', '$1$2$3', $css); // "0.1em" to ".1em", "1.10em" to "1.1em"
-    $css = preg_replace('/([: ])\.(0)+((?:pt|pc|in|mm|cm|em|ex|px)\b|%)(?=[^\{]*[;\}])/', '$1$2', $css); // ".0em" to "0"
-    $css = preg_replace('/([: ]0)0*(\.0*)?((?:pt|pc|in|mm|cm|em|ex|px)(?=[^\{]*[;\}])\b|%)/', '$1', $css); // "0.0em" to "0"
-    $css = preg_replace('/([: ]\d+)(\.0*)((?:pt|pc|in|mm|cm|em|ex|px)(?=[^\{]*[;\}])\b|%)/', '$1$3', $css); // "1.0em" to "1em"
-    $css = preg_replace('/([: ])0+(\d+|\d*\.\d+)((?:pt|pc|in|mm|cm|em|ex|px)(?=[^\{]*[;\}])\b|%)/', '$1$2$3', $css); // "001em" to "1em"
+    $css = preg_replace(
+        '/([: ])0+(\.\d+?)0*((?:pt|pc|in|mm|cm|em|ex|px)\b|%)(?=[^\{]*[;\}])/',
+        '$1$2$3',
+        $css
+    ); // "0.1em" to ".1em", "1.10em" to "1.1em"
+    $css = preg_replace(
+        '/([: ])\.(0)+((?:pt|pc|in|mm|cm|em|ex|px)\b|%)(?=[^\{]*[;\}])/',
+        '$1$2',
+        $css
+    ); // ".0em" to "0"
+    $css = preg_replace(
+        '/([: ]0)0*(\.0*)?((?:pt|pc|in|mm|cm|em|ex|px)(?=[^\{]*[;\}])\b|%)/',
+        '$1',
+        $css
+    ); // "0.0em" to "0"
+    $css = preg_replace(
+        '/([: ]\d+)(\.0*)((?:pt|pc|in|mm|cm|em|ex|px)(?=[^\{]*[;\}])\b|%)/',
+        '$1$3',
+        $css
+    ); // "1.0em" to "1em"
+    $css = preg_replace(
+        '/([: ])0+(\d+|\d*\.\d+)((?:pt|pc|in|mm|cm|em|ex|px)(?=[^\{]*[;\}])\b|%)/',
+        '$1$2$3',
+        $css
+    ); // "001em" to "1em"
 
     // shorten attributes (1em 1em 1em 1em -> 1em)
-    $css = preg_replace('/(?<![\w\-])((?:margin|padding|border|border-(?:width|radius)):)([\w\.]+)( \2)+(?=[;\}]| !)/', '$1$2', $css); // "1em 1em 1em 1em" to "1em"
-    $css = preg_replace('/(?<![\w\-])((?:margin|padding|border|border-(?:width)):)([\w\.]+) ([\w\.]+) \2 \3(?=[;\}]| !)/', '$1$2 $3', $css); // "1em 2em 1em 2em" to "1em 2em"
+    $css = preg_replace(
+        '/(?<![\w\-])((?:margin|padding|border|border-(?:width|radius)):)([\w\.]+)( \2)+(?=[;\}]| !)/',
+        '$1$2',
+        $css
+    ); // "1em 1em 1em 1em" to "1em"
+    $css = preg_replace(
+        '/(?<![\w\-])((?:margin|padding|border|border-(?:width)):)([\w\.]+) ([\w\.]+) \2 \3(?=[;\}]| !)/',
+        '$1$2 $3',
+        $css
+    ); // "1em 2em 1em 2em" to "1em 2em"
 
     // shorten colors
-    $css = preg_replace("/#([0-9a-fA-F]{1})\\1([0-9a-fA-F]{1})\\2([0-9a-fA-F]{1})\\3(?=[^\{]*[;\}])/", "#\\1\\2\\3", $css);
+    $css = preg_replace(
+        "/#([0-9a-fA-F]{1})\\1([0-9a-fA-F]{1})\\2([0-9a-fA-F]{1})\\3(?=[^\{]*[;\}])/",
+        "#\\1\\2\\3",
+        $css
+    );
+
+    // replace back protected strings
+    $quote_back_cb = function ($match) use (&$quote_storage) {
+        return $quote_storage[$match[1]];
+    };
+
+    $css = preg_replace_callback('/"STR(\d+)"/', $quote_back_cb, $css);
+    $css = trim($css);
 
     return $css;
 }
@@ -643,23 +658,6 @@ function css_onelinecomment_cb($matches) {
             break;
         }
 
-        // keep any quoted string that starts before a comment
-        $nextsqt = strpos($line, "'", $i);
-        $nextdqt = strpos($line, '"', $i);
-        if(min($nextsqt, $nextdqt) < $nextcom) {
-            $skipto = false;
-            if($nextsqt !== false && ($nextdqt === false || $nextsqt < $nextdqt)) {
-                $skipto = strpos($line, "'", $nextsqt+1) +1;
-            } else if ($nextdqt !== false) {
-                $skipto = strpos($line, '"', $nextdqt+1) +1;
-            }
-
-            if($skipto !== false) {
-                $i = $skipto;
-                continue;
-            }
-        }
-
         if($nexturl === false || $nextcom < $nexturl) {
             // no url anymore, strip comment and be done
             $i = $nextcom;
