@@ -1,4 +1,6 @@
 <?php
+use dokuwiki\Utf8\Sort;
+
 /**
  * ACL administration functions
  *
@@ -304,7 +306,7 @@ class admin_plugin_acl extends DokuWiki_Admin_Plugin
         while (count($a_ids) && count($b_ids)) {
             // compare each level from upper to lower
             // until a non-equal component is found
-            $cur_result = strcmp(array_shift($a_ids), array_shift($b_ids));
+            $cur_result = Sort::strcmp(array_shift($a_ids), array_shift($b_ids));
             if ($cur_result) {
                 // if one of the components is the last component and is a file
                 // and the other one is either of a deeper level or a directory,
@@ -589,7 +591,7 @@ class admin_plugin_acl extends DokuWiki_Admin_Plugin
         }
         $this->specials = array_filter($this->specials);
         $this->specials = array_unique($this->specials);
-        sort($this->specials);
+        Sort::sort($this->specials);
 
         foreach ($AUTH_ACL as $line) {
             $line = trim(preg_replace('/#.*$/', '', $line)); //ignore comments
@@ -608,8 +610,11 @@ class admin_plugin_acl extends DokuWiki_Admin_Plugin
         }
 
         $usersgroups = array_unique($usersgroups);
-        sort($usersgroups);
-        ksort($acl_config);
+        Sort::sort($usersgroups);
+        Sort::ksort($acl_config);
+        foreach (array_keys($acl_config) as $pagename) {
+            Sort::ksort($acl_config[$pagename]);
+        }
 
         $this->acl = $acl_config;
         $this->usersgroups = $usersgroups;
