@@ -2,8 +2,9 @@
 
 /**
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
- * 
+ *
+ * @author Jose Luis Sanches <jose.reis.sanches@gmail.com>
  * @author Paulo Carmino <contato@paulocarmino.com>
  */
 $lang['connectfail']           = 'Não foi possível conectar o LDAP: %s';
-$lang['domainfail']            = 'O LDAP não encontrou seu usuário';
+$lang['domainfail']            = 'O LDAP não encontrou seu utilizador';
