@@ -3,6 +3,10 @@
 /**
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
  *
+ * @author Petr Kajzar <petr.kajzar@centrum.cz>
+ * @author Aleksandr Selivanov <alexgearbox@yandex.ru>
+ * @author Robert Surý <rsurycz@seznam.cz>
+ * @author Martin Hořínek <hev@hev.cz>
  * @author Jonáš Dyba <jonas.dyba@gmail.com>
  * @author Bohumir Zamecnik <bohumir@zamecnik.org>
  * @author Zbynek Krivka <zbynek.krivka@seznam.cz>
@@ -48,6 +52,7 @@ $lang['_advanced']             = 'Pokročilá nastavení';
 $lang['_network']              = 'Nastavení sítě';
 $lang['_msg_setting_undefined'] = 'Chybí metadata položky.';
 $lang['_msg_setting_no_class'] = 'Chybí třída položky.';
+$lang['_msg_setting_no_known_class'] = 'Konfigurační třída není dostupná.';
 $lang['_msg_setting_no_default'] = 'Chybí výchozí hodnota položky.';
 $lang['title']                 = 'Název celé wiki';
 $lang['start']                 = 'Název úvodní stránky';
@@ -99,7 +104,7 @@ $lang['disableactions']        = 'Vypnout DokuWiki akce';
 $lang['disableactions_check']  = 'Zkontrolovat';
 $lang['disableactions_subscription'] = 'Přihlásit se/Odhlásit se ze seznamu pro odběr změn';
 $lang['disableactions_wikicode'] = 'Prohlížet zdrojové kódy/Export wiki textu';
-$lang['disableactions_profile_delete'] = 'Smazat vlasní účet';
+$lang['disableactions_profile_delete'] = 'Smazat vlastní účet';
 $lang['disableactions_other']  = 'Další akce (oddělené čárkou)';
 $lang['disableactions_rss']    = 'XMS syndikace (RSS)';
 $lang['auth_security_timeout'] = 'Časový limit pro autentikaci (v sekundách)';
@@ -112,8 +117,6 @@ $lang['indexdelay']            = 'Časová prodleva před indexací (v sekundác
 $lang['mailguard']             = 'Metoda "zamaskování" emailových adres';
 $lang['iexssprotect']          = 'Zkontrolovat nahrané soubory vůči možnému škodlivému JavaScriptu či HTML';
 $lang['usedraft']              = 'Během editace ukládat koncept automaticky';
-$lang['htmlok']                = 'Povolit vložené HTML';
-$lang['phpok']                 = 'Povolit vložené PHP';
 $lang['locktime']              = 'Maximální životnost zámkových souborů (v sekundách)';
 $lang['cachetime']             = 'Maximální životnost cache (v sekundách)';
 $lang['target____wiki']        = 'Cílové okno pro interní odkazy';
@@ -132,15 +135,19 @@ $lang['subscribe_time']        = 'Časový interval v sekundách, ve kterém jso
 $lang['notify']                = 'Posílat oznámení o změnách na následující emailovou adresu';
 $lang['registernotify']        = 'Posílat informace o nově registrovaných uživatelích na tuto mailovou adresu';
 $lang['mailfrom']              = 'E-mailová adresa, která se bude používat pro automatické maily';
+$lang['mailreturnpath']        = 'E-mailová adresa příjemce pro oznámení o nedoručení';
 $lang['mailprefix']            = 'Předpona předmětu e-mailu, která se bude používat pro automatické maily';
 $lang['htmlmail']              = 'Posílat emaily v HTML (hezčí ale větší). Při vypnutí budou posílány jen textové emaily.';
+$lang['dontlog']               = 'Zakázat protokolování pro tyto typy záznamů.';
 $lang['sitemap']               = 'Generovat Google sitemap (interval ve dnech)';
 $lang['rss_type']              = 'Typ XML kanálu';
 $lang['rss_linkto']            = 'XML kanál odkazuje na';
 $lang['rss_content']           = 'Co zobrazovat v položkách XML kanálu?';
 $lang['rss_update']            = 'Interval aktualizace XML kanálu (v sekundách)';
 $lang['rss_show_summary']      = 'XML kanál ukazuje souhrn v titulku';
+$lang['rss_show_deleted']      = 'XML kanál Zobrazit smazané kanály';
 $lang['rss_media']             = 'Jaký typ změn má být uveden v kanálu XML';
+$lang['rss_media_o_both']      = 'oba';
 $lang['rss_media_o_pages']     = 'stránky';
 $lang['rss_media_o_media']     = 'média';
 $lang['updatecheck']           = 'Kontrolovat aktualizace a bezpečnostní varování? DokuWiki potřebuje pro tuto funkci přístup k update.dokuwiki.org';
@@ -160,9 +167,15 @@ $lang['xsendfile']             = 'Používat X-Sendfile hlavničky pro download
 $lang['renderer_xhtml']        = 'Vykreslovací jádro pro hlavní (xhtml) výstup wiki';
 $lang['renderer__core']        = '%s (jádro DokuWiki)';
 $lang['renderer__plugin']      = '%s (plugin)';
+$lang['search_nslimit']        = 'Omezit vyhledávání na současných X jmenných prostorů. Když je vyhledávání provedeno ze stránky zanořeného jmenného prostoru, bude jako filtr přidáno prvních X jmenných prostorů.';
+$lang['search_fragment']       = 'Určete výchozí chování vyhledávání fragmentů';
+$lang['search_fragment_o_exact'] = 'přesný';
 $lang['search_fragment_o_starts_with'] = 'začíná s';
 $lang['search_fragment_o_ends_with'] = 'končí s';
 $lang['search_fragment_o_contains'] = 'obsahuje';
+$lang['trustedproxy']          = 'Důvěřovat proxy serverům odpovídajícím tomuto regulárním výrazu ohledně skutečné IP adresy klienta, kterou hlásí. Výchozí hodnota odpovídá místním sítím. Ponechejte prázdné, pokud nechcete důvěřovat žádné proxy.';
+$lang['_feature_flags']        = 'Feature flags';
+$lang['defer_js']              = 'Odložit spuštění javascriptu až po zpracování HTML kódu stránky. Zlepšuje vnímanou rychlost načtení stránky, ale může narušit funkci některých zásuvných modulů.';
 $lang['dnslookups']            = 'DokuWiki zjišťuje DNS jména pro vzdálené IP adresy uživatelů, kteří editují stránky. Pokud máte pomalý, nebo nefunkční DNS server, nebo nepotřebujete tuto funkci, tak tuto volbu zrušte.';
 $lang['jquerycdn']             = 'Mají být skripty jQuery a jQuery UI načítány z CDN?
 Vzniknou tím další HTTP dotazy, ale soubory se mohou načíst rychleji a uživatelé je už mohou mít ve vyrovnávací paměti.';
@@ -175,12 +188,6 @@ $lang['proxy____user']         = 'Proxy uživatelské jméno';
 $lang['proxy____pass']         = 'Proxy heslo';
 $lang['proxy____ssl']          = 'Použít SSL při připojení k proxy';
 $lang['proxy____except']       = 'Regulární výrazy pro URL, pro které bude přeskočena proxy.';
-$lang['safemodehack']          = 'Zapnout safemode hack';
-$lang['ftp____host']           = 'FTP server pro safemode hack';
-$lang['ftp____port']           = 'FTP port pro safemode hack';
-$lang['ftp____user']           = 'FTP uživatelské jméno pro safemode hack';
-$lang['ftp____pass']           = 'FTP heslo pro safemode hack';
-$lang['ftp____root']           = 'FTP kořenový adresář pro safemode hack';
 $lang['license_o_']            = 'Nic nevybráno';
 $lang['typography_o_0']        = 'vypnuto';
 $lang['typography_o_1']        = 'Pouze uvozovky';
