@@ -98,8 +98,6 @@ $lang['indexdelay']            = 'Várakozás indexelés előtt (másodperc)';
 $lang['mailguard']             = 'Email címek olvashatatlanná tétele címgyűjtők számára';
 $lang['iexssprotect']          = 'Feltöltött fájlok ellenőrzése kártékony JavaScript vagy HTML kód elkerülésére';
 $lang['usedraft']              = 'Piszkozat automatikus mentése szerkesztés alatt';
-$lang['htmlok']                = 'Beágyazott HTML engedélyezése';
-$lang['phpok']                 = 'Beágyazott PHP engedélyezése';
 $lang['locktime']              = 'Oldal-zárolás maximális időtartama (másodperc)';
 $lang['cachetime']             = 'A gyorsítótár maximális élettartama (másodperc)';
 $lang['target____wiki']        = 'Cél-ablak belső hivatkozásokhoz';
