@@ -102,8 +102,6 @@ $lang['indexdelay']            = 'インデックスを許可（何秒後）';
 $lang['mailguard']             = 'メールアドレス保護';
 $lang['iexssprotect']          = 'アップロードファイルに悪意のあるJavaScriptやHTMLが含まれていないかチェックする';
 $lang['usedraft']              = '編集中の自動保存（ドラフト）機能を使用';
-$lang['htmlok']                = 'HTML埋め込みを許可する';
-$lang['phpok']                 = 'PHP埋め込みを許可する';
 $lang['locktime']              = 'ファイルロック期限（秒）';
 $lang['cachetime']             = 'キャッシュ保持時間（秒）';
 $lang['target____wiki']        = '内部リンクのtarget属性';
