@@ -3,7 +3,15 @@
 /**
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
  *
+ * @author Gilson Caldeira <gilsoncaldeira@gmail.com>
+ * @author Paul Nizan <paul_nizan@hormail.com>
+ * @author Eduardo Mozart de Oliveira <eduardomozart182@gmail.com>
+ * @author ANDRE BASSANI DE FREITAS <dedebf@gmail.com>
+ * @author Aleksandr Selivanov <alexgearbox@yandex.ru>
+ * @author Davi Jorge <davimoises2015@hotmail.com>
+ * @author Schopf <pschopf@gmail.com>
  * @author Frederico Gonçalves Guimarães <frederico@teia.bio.br>
+ * @author Márcio Gomes Gonçalves <gomes@metha.com.br>
  * @author Felipe Castro <fefcas@gmail.com>
  * @author Lucien Raven <lucienraven@yahoo.com.br>
  * @author Enrico Nicoletto <liverig@gmail.com>
@@ -46,6 +54,7 @@ $lang['_advanced']             = 'Configurações avançadas';
 $lang['_network']              = 'Configurações de rede';
 $lang['_msg_setting_undefined'] = 'Nenhum metadado configurado.';
 $lang['_msg_setting_no_class'] = 'Nenhuma classe definida.';
+$lang['_msg_setting_no_known_class'] = 'Classe de configuração não disponível.';
 $lang['_msg_setting_no_default'] = 'Nenhum valor padrão.';
 $lang['title']                 = 'Título do wiki';
 $lang['start']                 = 'Nome da página inicial';
@@ -99,14 +108,13 @@ $lang['auth_security_timeout'] = 'Tempo limite de segurança para autenticaçõe
 $lang['securecookie']          = 'Os cookies definidos via HTTPS devem ser enviados para o navegador somente via HTTPS? Desabilite essa opção quando somente a autenticação do seu wiki for realizada de maneira segura via SSL e a navegação, de maneira insegura.';
 $lang['remote']                = 'Habilitar o sistema de API remota. Isso permite que outras aplicações acessem o wiki via XML-RPC ou outros mecanismos.';
 $lang['remoteuser']            = 'Restringir o acesso à API remota aos grupos ou usuários definidos aqui (separados por vírgulas). Deixe em branco para permitir o acesso a qualquer um.';
+$lang['remotecors']            = 'Habilite o compartilhamento de recursos entre origens (CORS) para as interfaces remotas. Asterisco (*) para permitir todas as origens. Deixe em branco para negar o CORS.';
 $lang['usewordblock']          = 'Bloquear spam baseado em lista de palavras';
 $lang['relnofollow']           = 'Usar rel="nofollow" em links externos';
 $lang['indexdelay']            = 'Tempo de espera antes da indexação (seg)';
 $lang['mailguard']             = 'Obscurecer endereços de e-mail';
 $lang['iexssprotect']          = 'Verificar a existência de possíveis códigos maliciosos em HTML ou JavaScript nos arquivos enviados';
 $lang['usedraft']              = 'Salvar o rascunho automaticamente durante a edição';
-$lang['htmlok']                = 'Permitir incorporação de HTML';
-$lang['phpok']                 = 'Permitir incorporação de PHP';
 $lang['locktime']              = 'Tempo máximo para o bloqueio de arquivos (seg)';
 $lang['cachetime']             = 'Tempo máximo para o cache (seg)';
 $lang['target____wiki']        = 'Parâmetro "target" para links internos';
@@ -128,12 +136,14 @@ $lang['mailfrom']              = 'Endereço de e-mail a ser utilizado para mensa
 $lang['mailreturnpath']        = 'Endereço de e-mail do destinatário para notificações de falha de entrega';
 $lang['mailprefix']            = 'Prefixo do assunto dos e-mails de envio automático';
 $lang['htmlmail']              = 'Enviar e-mail HTML multipartes, que têm uma aparência melhor, mas um tamanho maior. Desabilite para enviar e-mails em texto puro.';
+$lang['dontlog']               = 'Desabilita o registro de log para os seguintes tipos de logs.';
 $lang['sitemap']               = 'Gerar Google Sitemap (dias)';
 $lang['rss_type']              = 'Tipo de fonte XML';
 $lang['rss_linkto']            = 'Os links da fonte XML apontam para';
 $lang['rss_content']           = 'O que deve ser exibido nos itens da fonte XML?';
 $lang['rss_update']            = 'Intervalo de atualização da fonte XML (seg)';
 $lang['rss_show_summary']      = 'Resumo de exibição da fonte XML no título';
+$lang['rss_show_deleted']      = 'Feed XML Mostrar feeds excluídos';
 $lang['rss_media']             = 'Que tipo de alterações devem ser listadas na fonte XML?';
 $lang['rss_media_o_both']      = 'ambos';
 $lang['rss_media_o_pages']     = 'páginas';
@@ -155,6 +165,16 @@ $lang['xsendfile']             = 'Usar o cabeçalho "X-Sendfile" para permitir q
 $lang['renderer_xhtml']        = 'Renderizador a ser utilizado para a saída principal (xhtml) do wiki';
 $lang['renderer__core']        = '%s (núcleo do DokuWiki)';
 $lang['renderer__plugin']      = '%s ("plug-in")';
+$lang['search_nslimit']        = 'Limite a pesquisa aos atuais X espaços de nomes. Quando uma pesquisa é executada a partir de uma página em um espaço de nomes mais interno, os primeiros X espaços de nomes serão adicionados como filtro';
+$lang['search_fragment']       = 'Especifique o comportamento padrão da pesquisa de fragmentos';
+$lang['search_fragment_o_exact'] = 'exato';
+$lang['search_fragment_o_starts_with'] = 'começa com';
+$lang['search_fragment_o_ends_with'] = 'termina com';
+$lang['search_fragment_o_contains'] = 'contém';
+$lang['trustedproxy']          = 'Confie nos proxies de encaminhamento que correspondem a essa expressão regular sobre o verdadeiro IP do cliente que eles relatam. O padrão corresponde às redes locais. Deixe em branco para não confiar em proxy.';
+$lang['_feature_flags']        = 'Sinalizadores de recursos';
+$lang['defer_js']              = 'Adie o javascript para ser executado após a análise do HTML da página. Melhora a velocidade percebida da página, mas pode interromper um pequeno número de plugins.';
+$lang['hidewarnings']          = 'Não exiba nenhum aviso emitido pelo PHP. Isso pode facilitar a transição para PHP8+. Os avisos ainda serão registrados no log de erros e devem ser relatados.';
 $lang['dnslookups']            = 'O DokuWiki procurará pelo nome de host dos endereços IP remotos dos usuários que estão editando as páginas. Caso você tenha um DNS lento, ele não esteja funcionando ou, ainda, você não queira esse recurso, desabilite essa opção.';
 $lang['jquerycdn']             = 'Os scripts jQuery e jQuery UI devem ser carregados a partir de uma CND? Isso adiciona requisições HTTP adicionais, mas os arquivos podem carregar mais rapidamente e os usuários podem já tê-los no cache.';
 $lang['jquerycdn_o_0']         = 'Sem CDN, somente entrega local';
@@ -166,12 +186,6 @@ $lang['proxy____user']         = 'Nome de usuário do proxy';
 $lang['proxy____pass']         = 'Senha do proxy';
 $lang['proxy____ssl']          = 'Usar SSL para conectar ao proxy';
 $lang['proxy____except']       = 'Expressões regulares de URL para excessão de proxy.';
-$lang['safemodehack']          = 'Habilitar o contorno de segurança';
-$lang['ftp____host']           = 'Servidor FTP para o contorno de segurança';
-$lang['ftp____port']           = 'Porta do FTP para o contorno de segurança';
-$lang['ftp____user']           = 'Nome do usuário FTP para o contorno de segurança';
-$lang['ftp____pass']           = 'Senha do usuário FTP para o contorno de segurança';
-$lang['ftp____root']           = 'Diretório raiz do FTP para o contorno de segurança';
 $lang['license_o_']            = 'Nenhuma escolha';
 $lang['typography_o_0']        = 'nenhuma';
 $lang['typography_o_1']        = 'excluir aspas simples';
