@@ -1,15 +1,18 @@
 <?php
+
 /**
- * ukrainian language file
- *
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
+ *
+ * @author velmyshanovnyi <velmyshanovnyi@gmail.com>
+ * @author Dmytro Marchenko <dmytro.marchenko1989@gmail.com>
+ * @author Oleksii <alexey.furashev@gmail.com>
+ * @author Vitaly <vitaly.balashov@smuzzy.com.ua>
  * @author Oleksiy Voronin <ovoronin@gmail.com>
- * @author serg_stetsuk@ukr.net
- * @author okunia@gmail.com
+ * @author serg_stetsuk <serg_stetsuk@ukr.net>
  * @author Oleksandr Kunytsia <okunia@gmail.com>
- * @author Uko uko@uar.net
- * @author Ulrikhe Lukoie  <lukoie@gmail>.com
- * @author Kate Arzamastseva pshns@ukr.net
+ * @author Maksim <nikropol@yandex.ru>
+ * @author Nina Zolotova <nina-z@i.ua>
+ * @author Roman <vsmemorial@gmail.com>
  */
 $lang['menu']                  = 'Налаштування Вікі';
 $lang['error']                 = 'Параметри не збережено через помилкові значення. Будь ласка, перегляньте ваші зміни та спробуйте ще раз
@@ -36,8 +39,6 @@ $lang['_media']                = 'Налаштування медіа';
 $lang['_notifications']        = 'Налаштування сповіщень';
 $lang['_advanced']             = 'Розширені налаштування';
 $lang['_network']              = 'Налаштування мережі';
-$lang['_plugin_sufix']         = 'Налаштування (доданок)';
-$lang['_template_sufix']       = 'Налаштування (шаблон)';
 $lang['_msg_setting_undefined'] = 'Немає метаданих параметру.';
 $lang['_msg_setting_no_class'] = 'Немає класу параметру.';
 $lang['_msg_setting_no_default'] = 'Немає значення за замовчуванням.';
@@ -58,7 +59,7 @@ $lang['breadcrumbs']           = 'Ви відвідали (кількість с
 $lang['youarehere']            = 'Показувати "Ви тут"';
 $lang['fullpath']              = 'Повний шлях до документу';
 $lang['typography']            = 'Замінювати типографські символи';
-$lang['dformat']               = 'Формат дати (дивіться функцію <a href="http://www.php.net/strftime">strftime</a> PHP)';
+$lang['dformat']               = 'Формат дати (дивіться функцію <a href="http://php.net/strftime">strftime</a> PHP)';
 $lang['signature']             = 'Підпис';
 $lang['showuseras']            = 'Що вказувати при відображенні користувача, який востаннє редагував сторінку';
 $lang['toptoclevel']           = 'Мінімальний рівень для змісту';
@@ -92,8 +93,6 @@ $lang['indexdelay']            = 'Затримка перед індексаці
 $lang['mailguard']             = 'Кодувати адреси e-mail';
 $lang['iexssprotect']          = 'Перевірте оновлені файли на можливі заборонені Javascript чи HTML коди';
 $lang['usedraft']              = 'Автоматично зберігати чернетку при редагуванні';
-$lang['htmlok']                = 'Дозволити HTML';
-$lang['phpok']                 = 'Дозволити PHP';
 $lang['locktime']              = 'Час блокування (сек)';
 $lang['cachetime']             = 'Максимальний вік кешу (сек)';
 $lang['target____wiki']        = 'Target для внутрішніх посилань';
@@ -102,7 +101,6 @@ $lang['target____extern']      = 'Target для зовнішніх посила
 $lang['target____media']       = 'Target для медіа-посилань';
 $lang['target____windows']     = 'Target для посилань на мережеві папки';
 $lang['refcheck']              = 'Перевіряти посилання на медіа-файлі';
-$lang['refshow']               = 'Показувати кількість медіа-посилань';
 $lang['gdlib']                 = 'Версія GD Lib';
 $lang['im_convert']            = 'Шлях до ImageMagick';
 $lang['jpg_quality']           = 'Якість компресії JPG (0-100)';
@@ -119,6 +117,8 @@ $lang['rss_linkto']            = 'посилання в RSS';
 $lang['rss_content']           = 'Що відображати в пунктах XML-feed';
 $lang['rss_update']            = 'Інтервал оновлення RSS (сек)';
 $lang['rss_show_summary']      = 'Показувати підсумки змін в заголовку XML-feed';
+$lang['rss_media_o_both']      = 'обидва';
+$lang['rss_media_o_pages']     = 'сторінки';
 $lang['updatecheck']           = 'Перевірити наявність оновлень чи попереджень безпеки? Для цього ДокуВікі необхідно зв\'язатися зі update.dokuwiki.org.';
 $lang['userewrite']            = 'Красиві URL';
 $lang['useslash']              = 'Слеш, як розділювач просторів імен в URL';
@@ -135,18 +135,13 @@ $lang['xsendfile']             = 'Використовувати заголов
 $lang['renderer_xhtml']        = 'Транслятор (Renderer) для основного виводу wiki (xhtml)';
 $lang['renderer__core']        = '%s (ядро докуВікі)';
 $lang['renderer__plugin']      = '%s (доданок)';
+$lang['search_fragment_o_exact'] = 'точно';
 $lang['proxy____host']         = 'Адреса Proxy';
 $lang['proxy____port']         = 'Порт Proxy';
 $lang['proxy____user']         = 'Користувач Proxy';
 $lang['proxy____pass']         = 'Пароль Proxy';
 $lang['proxy____ssl']          = 'Використовувати ssl для з\'єднання з Proxy';
 $lang['proxy____except']       = 'Регулярний вираз для веб-адреси, яку проксі-сервер пропустить.';
-$lang['safemodehack']          = 'Увімкнути хак safemode';
-$lang['ftp____host']           = 'FTP-сервер для хаку safemode';
-$lang['ftp____port']           = 'FTP-порт для хаку safemode';
-$lang['ftp____user']           = 'Користувач FTP для хаку safemode';
-$lang['ftp____pass']           = 'Пароль FTP для хаку safemode';
-$lang['ftp____root']           = 'Коренева папка FTP для хаку safemode';
 $lang['license_o_']            = 'не вибрано';
 $lang['typography_o_0']        = 'жодного';
 $lang['typography_o_1']        = 'Лише подвійні лапки';
