@@ -13,7 +13,7 @@ class helper_plugin_popularity extends Dokuwiki_Plugin
     /**
      * The url where the data should be sent
      */
-    public $submitUrl = 'http://update.dokuwiki.org/popularity.php';
+    public $submitUrl = 'https://update.dokuwiki.org/popularity.php';
 
     /**
      * Name of the file which determine if the the autosubmit is enabled,
@@ -103,6 +103,25 @@ class helper_plugin_popularity extends Dokuwiki_Plugin
         return $string;
     }
 
+    /**
+     * Initialize an empty list to be used in file traversing
+     *
+     * @return array
+     * @see searchCountCallback
+     */
+    protected function initEmptySearchList()
+    {
+        return $list = array_fill_keys([
+            'file_count',
+            'file_size',
+            'file_max',
+            'file_min',
+            'dir_count',
+            'dir_nest',
+            'file_oldest'
+        ], 0);
+    }
+
     /**
      * Gather all information
      *
@@ -132,7 +151,7 @@ class helper_plugin_popularity extends Dokuwiki_Plugin
         $data['conf_template'] = $conf['template'];
 
         // number and size of pages
-        $list = array();
+        $list = $this->initEmptySearchList();
         search($list, $conf['datadir'], array($this, 'searchCountCallback'), array('all'=>false), '');
         $data['page_count']    = $list['file_count'];
         $data['page_size']     = $list['file_size'];
@@ -145,7 +164,7 @@ class helper_plugin_popularity extends Dokuwiki_Plugin
         unset($list);
 
         // number and size of media
-        $list = array();
+        $list = $this->initEmptySearchList();
         search($list, $conf['mediadir'], array($this, 'searchCountCallback'), array('all'=>true));
         $data['media_count']    = $list['file_count'];
         $data['media_size']     = $list['file_size'];
@@ -157,7 +176,7 @@ class helper_plugin_popularity extends Dokuwiki_Plugin
         unset($list);
 
         // number and size of cache
-        $list = array();
+        $list = $this->initEmptySearchList();
         search($list, $conf['cachedir'], array($this, 'searchCountCallback'), array('all'=>true));
         $data['cache_count']    = $list['file_count'];
         $data['cache_size']     = $list['file_size'];
@@ -167,7 +186,7 @@ class helper_plugin_popularity extends Dokuwiki_Plugin
         unset($list);
 
         // number and size of index
-        $list = array();
+        $list = $this->initEmptySearchList();
         search($list, $conf['indexdir'], array($this, 'searchCountCallback'), array('all'=>true));
         $data['index_count']    = $list['file_count'];
         $data['index_size']     = $list['file_size'];
@@ -177,7 +196,7 @@ class helper_plugin_popularity extends Dokuwiki_Plugin
         unset($list);
 
         // number and size of meta
-        $list = array();
+        $list = $this->initEmptySearchList();
         search($list, $conf['metadir'], array($this, 'searchCountCallback'), array('all'=>true));
         $data['meta_count']    = $list['file_count'];
         $data['meta_size']     = $list['file_size'];
@@ -187,7 +206,7 @@ class helper_plugin_popularity extends Dokuwiki_Plugin
         unset($list);
 
         // number and size of attic
-        $list = array();
+        $list = $this->initEmptySearchList();
         search($list, $conf['olddir'], array($this, 'searchCountCallback'), array('all'=>true));
         $data['attic_count']    = $list['file_count'];
         $data['attic_size']     = $list['file_size'];
@@ -203,7 +222,7 @@ class helper_plugin_popularity extends Dokuwiki_Plugin
         }
 
         // calculate edits per day
-        $list = @file($conf['metadir'].'/_dokuwiki.changes');
+        $list = (array) @file($conf['metadir'].'/_dokuwiki.changes');
         $count = count($list);
         if ($count > 2) {
             $first = (int) substr(array_shift($list), 0, 10);
